<?php

/**
 * This file is automatically generated. Use 'arc liberate' to rebuild it.
 *
 * @generated
 * @phutil-library-version 2
 */
phutil_register_library_map(array(
  '__library_version__' => 2,
  'class' => array(
    'AASTNode' => 'parser/aast/api/AASTNode.php',
    'AASTNodeList' => 'parser/aast/api/AASTNodeList.php',
    'AASTToken' => 'parser/aast/api/AASTToken.php',
    'AASTTree' => 'parser/aast/api/AASTTree.php',
    'AbstractDirectedGraph' => 'utils/AbstractDirectedGraph.php',
    'AbstractDirectedGraphTestCase' => 'utils/__tests__/AbstractDirectedGraphTestCase.php',
    'ArcanistAbstractMethodBodyXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistAbstractMethodBodyXHPASTLinterRule.php',
    'ArcanistAbstractMethodBodyXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistAbstractMethodBodyXHPASTLinterRuleTestCase.php',
    'ArcanistAbstractPrivateMethodXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistAbstractPrivateMethodXHPASTLinterRule.php',
    'ArcanistAbstractPrivateMethodXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistAbstractPrivateMethodXHPASTLinterRuleTestCase.php',
    'ArcanistAlias' => 'toolset/ArcanistAlias.php',
    'ArcanistAliasEffect' => 'toolset/ArcanistAliasEffect.php',
    'ArcanistAliasEngine' => 'toolset/ArcanistAliasEngine.php',
    'ArcanistAliasFunctionXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistAliasFunctionXHPASTLinterRule.php',
    'ArcanistAliasFunctionXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistAliasFunctionXHPASTLinterRuleTestCase.php',
    'ArcanistAliasWorkflow' => 'toolset/workflow/ArcanistAliasWorkflow.php',
    'ArcanistAliasesConfigOption' => 'config/option/ArcanistAliasesConfigOption.php',
    'ArcanistAmendWorkflow' => 'workflow/ArcanistAmendWorkflow.php',
    'ArcanistAnoidWorkflow' => 'workflow/ArcanistAnoidWorkflow.php',
    'ArcanistArcConfigurationEngineExtension' => 'config/arc/ArcanistArcConfigurationEngineExtension.php',
    'ArcanistArcToolset' => 'toolset/ArcanistArcToolset.php',
    'ArcanistArcWorkflow' => 'toolset/workflow/ArcanistArcWorkflow.php',
    'ArcanistArrayCombineXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistArrayCombineXHPASTLinterRule.php',
    'ArcanistArrayCombineXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistArrayCombineXHPASTLinterRuleTestCase.php',
    'ArcanistArrayIndexSpacingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistArrayIndexSpacingXHPASTLinterRule.php',
    'ArcanistArrayIndexSpacingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistArrayIndexSpacingXHPASTLinterRuleTestCase.php',
    'ArcanistArraySeparatorXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistArraySeparatorXHPASTLinterRule.php',
    'ArcanistArraySeparatorXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistArraySeparatorXHPASTLinterRuleTestCase.php',
    'ArcanistArrayValueXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistArrayValueXHPASTLinterRule.php',
    'ArcanistArrayValueXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistArrayValueXHPASTLinterRuleTestCase.php',
    'ArcanistBaseCommitParser' => 'parser/ArcanistBaseCommitParser.php',
    'ArcanistBaseCommitParserTestCase' => 'parser/__tests__/ArcanistBaseCommitParserTestCase.php',
    'ArcanistBaseXHPASTLinter' => 'lint/linter/ArcanistBaseXHPASTLinter.php',
    'ArcanistBinaryExpressionSpacingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistBinaryExpressionSpacingXHPASTLinterRule.php',
    'ArcanistBinaryExpressionSpacingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistBinaryExpressionSpacingXHPASTLinterRuleTestCase.php',
    'ArcanistBinaryNumericScalarCasingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistBinaryNumericScalarCasingXHPASTLinterRule.php',
    'ArcanistBinaryNumericScalarCasingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistBinaryNumericScalarCasingXHPASTLinterRuleTestCase.php',
    'ArcanistBlacklistedFunctionXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistBlacklistedFunctionXHPASTLinterRule.php',
    'ArcanistBlacklistedFunctionXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistBlacklistedFunctionXHPASTLinterRuleTestCase.php',
    'ArcanistBlindlyTrustHTTPEngineExtension' => 'configuration/ArcanistBlindlyTrustHTTPEngineExtension.php',
    'ArcanistBookmarksWorkflow' => 'workflow/ArcanistBookmarksWorkflow.php',
    'ArcanistBoolConfigOption' => 'config/option/ArcanistBoolConfigOption.php',
    'ArcanistBraceFormattingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistBraceFormattingXHPASTLinterRule.php',
    'ArcanistBraceFormattingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistBraceFormattingXHPASTLinterRuleTestCase.php',
    'ArcanistBranchesWorkflow' => 'workflow/ArcanistBranchesWorkflow.php',
    'ArcanistBrowseCommitHardpointQuery' => 'browse/query/ArcanistBrowseCommitHardpointQuery.php',
    'ArcanistBrowseCommitURIHardpointQuery' => 'browse/query/ArcanistBrowseCommitURIHardpointQuery.php',
    'ArcanistBrowseObjectNameURIHardpointQuery' => 'browse/query/ArcanistBrowseObjectNameURIHardpointQuery.php',
    'ArcanistBrowsePathURIHardpointQuery' => 'browse/query/ArcanistBrowsePathURIHardpointQuery.php',
    'ArcanistBrowseRef' => 'browse/ref/ArcanistBrowseRef.php',
    'ArcanistBrowseRefInspector' => 'inspector/ArcanistBrowseRefInspector.php',
    'ArcanistBrowseRevisionURIHardpointQuery' => 'browse/query/ArcanistBrowseRevisionURIHardpointQuery.php',
    'ArcanistBrowseURIHardpointQuery' => 'browse/query/ArcanistBrowseURIHardpointQuery.php',
    'ArcanistBrowseURIRef' => 'browse/ref/ArcanistBrowseURIRef.php',
    'ArcanistBrowseWorkflow' => 'browse/workflow/ArcanistBrowseWorkflow.php',
    'ArcanistBuildBuildplanHardpointQuery' => 'ref/build/ArcanistBuildBuildplanHardpointQuery.php',
    'ArcanistBuildPlanRef' => 'ref/buildplan/ArcanistBuildPlanRef.php',
    'ArcanistBuildPlanSymbolRef' => 'ref/buildplan/ArcanistBuildPlanSymbolRef.php',
    'ArcanistBuildRef' => 'ref/build/ArcanistBuildRef.php',
    'ArcanistBuildSymbolRef' => 'ref/build/ArcanistBuildSymbolRef.php',
    'ArcanistBuildableBuildsHardpointQuery' => 'ref/buildable/ArcanistBuildableBuildsHardpointQuery.php',
    'ArcanistBuildableRef' => 'ref/buildable/ArcanistBuildableRef.php',
    'ArcanistBuildableSymbolRef' => 'ref/buildable/ArcanistBuildableSymbolRef.php',
    'ArcanistBundle' => 'parser/ArcanistBundle.php',
    'ArcanistBundleTestCase' => 'parser/__tests__/ArcanistBundleTestCase.php',
    'ArcanistCSSLintLinter' => 'lint/linter/ArcanistCSSLintLinter.php',
    'ArcanistCSSLintLinterTestCase' => 'lint/linter/__tests__/ArcanistCSSLintLinterTestCase.php',
    'ArcanistCSharpLinter' => 'lint/linter/ArcanistCSharpLinter.php',
    'ArcanistCallConduitWorkflow' => 'workflow/ArcanistCallConduitWorkflow.php',
    'ArcanistCallParenthesesXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistCallParenthesesXHPASTLinterRule.php',
    'ArcanistCallParenthesesXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistCallParenthesesXHPASTLinterRuleTestCase.php',
    'ArcanistCallTimePassByReferenceXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistCallTimePassByReferenceXHPASTLinterRule.php',
    'ArcanistCallTimePassByReferenceXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistCallTimePassByReferenceXHPASTLinterRuleTestCase.php',
    'ArcanistCapabilityNotSupportedException' => 'workflow/exception/ArcanistCapabilityNotSupportedException.php',
    'ArcanistCastSpacingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistCastSpacingXHPASTLinterRule.php',
    'ArcanistCastSpacingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistCastSpacingXHPASTLinterRuleTestCase.php',
    'ArcanistCheckstyleXMLLintRenderer' => 'lint/renderer/ArcanistCheckstyleXMLLintRenderer.php',
    'ArcanistChmodLinter' => 'lint/linter/ArcanistChmodLinter.php',
    'ArcanistChmodLinterTestCase' => 'lint/linter/__tests__/ArcanistChmodLinterTestCase.php',
    'ArcanistClassExtendsObjectXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistClassExtendsObjectXHPASTLinterRule.php',
    'ArcanistClassExtendsObjectXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistClassExtendsObjectXHPASTLinterRuleTestCase.php',
    'ArcanistClassFilenameMismatchXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistClassFilenameMismatchXHPASTLinterRule.php',
    'ArcanistClassMustBeDeclaredAbstractXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistClassMustBeDeclaredAbstractXHPASTLinterRule.php',
    'ArcanistClassMustBeDeclaredAbstractXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistClassMustBeDeclaredAbstractXHPASTLinterRuleTestCase.php',
    'ArcanistClassNameLiteralXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistClassNameLiteralXHPASTLinterRule.php',
    'ArcanistClassNameLiteralXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistClassNameLiteralXHPASTLinterRuleTestCase.php',
    'ArcanistCloseRevisionWorkflow' => 'workflow/ArcanistCloseRevisionWorkflow.php',
    'ArcanistClosureLinter' => 'lint/linter/ArcanistClosureLinter.php',
    'ArcanistClosureLinterTestCase' => 'lint/linter/__tests__/ArcanistClosureLinterTestCase.php',
    'ArcanistCoffeeLintLinter' => 'lint/linter/ArcanistCoffeeLintLinter.php',
    'ArcanistCoffeeLintLinterTestCase' => 'lint/linter/__tests__/ArcanistCoffeeLintLinterTestCase.php',
    'ArcanistCommand' => 'toolset/command/ArcanistCommand.php',
    'ArcanistCommentRemover' => 'parser/ArcanistCommentRemover.php',
    'ArcanistCommentRemoverTestCase' => 'parser/__tests__/ArcanistCommentRemoverTestCase.php',
    'ArcanistCommentSpacingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistCommentSpacingXHPASTLinterRule.php',
    'ArcanistCommentStyleXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistCommentStyleXHPASTLinterRule.php',
    'ArcanistCommentStyleXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistCommentStyleXHPASTLinterRuleTestCase.php',
    'ArcanistCommitGraph' => 'repository/graph/ArcanistCommitGraph.php',
    'ArcanistCommitGraphPartition' => 'repository/graph/ArcanistCommitGraphPartition.php',
    'ArcanistCommitGraphPartitionQuery' => 'repository/graph/ArcanistCommitGraphPartitionQuery.php',
    'ArcanistCommitGraphQuery' => 'repository/graph/query/ArcanistCommitGraphQuery.php',
    'ArcanistCommitGraphSet' => 'repository/graph/ArcanistCommitGraphSet.php',
    'ArcanistCommitGraphSetQuery' => 'repository/graph/ArcanistCommitGraphSetQuery.php',
    'ArcanistCommitGraphSetTreeView' => 'repository/graph/view/ArcanistCommitGraphSetTreeView.php',
    'ArcanistCommitGraphSetView' => 'repository/graph/view/ArcanistCommitGraphSetView.php',
    'ArcanistCommitGraphTestCase' => 'repository/graph/__tests__/ArcanistCommitGraphTestCase.php',
    'ArcanistCommitNode' => 'repository/graph/ArcanistCommitNode.php',
    'ArcanistCommitRef' => 'ref/commit/ArcanistCommitRef.php',
    'ArcanistCommitSymbolRef' => 'ref/commit/ArcanistCommitSymbolRef.php',
    'ArcanistCommitSymbolRefInspector' => 'ref/commit/ArcanistCommitSymbolRefInspector.php',
    'ArcanistCommitUpstreamHardpointQuery' => 'query/ArcanistCommitUpstreamHardpointQuery.php',
    'ArcanistCommitWorkflow' => 'workflow/ArcanistCommitWorkflow.php',
    'ArcanistCompilerLintRenderer' => 'lint/renderer/ArcanistCompilerLintRenderer.php',
    'ArcanistComposerLinter' => 'lint/linter/ArcanistComposerLinter.php',
    'ArcanistComprehensiveLintEngine' => 'lint/engine/ArcanistComprehensiveLintEngine.php',
    'ArcanistConcatenationOperatorXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistConcatenationOperatorXHPASTLinterRule.php',
    'ArcanistConcatenationOperatorXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistConcatenationOperatorXHPASTLinterRuleTestCase.php',
    'ArcanistConduitAuthenticationException' => 'exception/ArcanistConduitAuthenticationException.php',
    'ArcanistConduitCallFuture' => 'conduit/ArcanistConduitCallFuture.php',
    'ArcanistConduitEngine' => 'conduit/ArcanistConduitEngine.php',
    'ArcanistConduitException' => 'conduit/ArcanistConduitException.php',
    'ArcanistConfigOption' => 'config/option/ArcanistConfigOption.php',
    'ArcanistConfiguration' => 'configuration/ArcanistConfiguration.php',
    'ArcanistConfigurationDrivenLintEngine' => 'lint/engine/ArcanistConfigurationDrivenLintEngine.php',
    'ArcanistConfigurationDrivenUnitTestEngine' => 'unit/engine/ArcanistConfigurationDrivenUnitTestEngine.php',
    'ArcanistConfigurationEngine' => 'config/ArcanistConfigurationEngine.php',
    'ArcanistConfigurationEngineExtension' => 'config/ArcanistConfigurationEngineExtension.php',
    'ArcanistConfigurationManager' => 'configuration/ArcanistConfigurationManager.php',
    'ArcanistConfigurationSource' => 'config/source/ArcanistConfigurationSource.php',
    'ArcanistConfigurationSourceList' => 'config/ArcanistConfigurationSourceList.php',
    'ArcanistConfigurationSourceValue' => 'config/ArcanistConfigurationSourceValue.php',
    'ArcanistConsoleLintRenderer' => 'lint/renderer/ArcanistConsoleLintRenderer.php',
    'ArcanistConsoleLintRendererTestCase' => 'lint/renderer/__tests__/ArcanistConsoleLintRendererTestCase.php',
    'ArcanistConstructorParenthesesXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistConstructorParenthesesXHPASTLinterRule.php',
    'ArcanistConstructorParenthesesXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistConstructorParenthesesXHPASTLinterRuleTestCase.php',
    'ArcanistContinueInsideSwitchXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistContinueInsideSwitchXHPASTLinterRule.php',
    'ArcanistContinueInsideSwitchXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistContinueInsideSwitchXHPASTLinterRuleTestCase.php',
    'ArcanistControlStatementSpacingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistControlStatementSpacingXHPASTLinterRule.php',
    'ArcanistControlStatementSpacingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistControlStatementSpacingXHPASTLinterRuleTestCase.php',
    'ArcanistCoverWorkflow' => 'workflow/ArcanistCoverWorkflow.php',
    'ArcanistCppcheckLinter' => 'lint/linter/ArcanistCppcheckLinter.php',
    'ArcanistCppcheckLinterTestCase' => 'lint/linter/__tests__/ArcanistCppcheckLinterTestCase.php',
    'ArcanistCpplintLinter' => 'lint/linter/ArcanistCpplintLinter.php',
    'ArcanistCpplintLinterTestCase' => 'lint/linter/__tests__/ArcanistCpplintLinterTestCase.php',
    'ArcanistCurlyBraceArrayIndexXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistCurlyBraceArrayIndexXHPASTLinterRule.php',
    'ArcanistCurlyBraceArrayIndexXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistCurlyBraceArrayIndexXHPASTLinterRuleTestCase.php',
    'ArcanistDeclarationParenthesesXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistDeclarationParenthesesXHPASTLinterRule.php',
    'ArcanistDeclarationParenthesesXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistDeclarationParenthesesXHPASTLinterRuleTestCase.php',
    'ArcanistDefaultParametersXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistDefaultParametersXHPASTLinterRule.php',
    'ArcanistDefaultParametersXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistDefaultParametersXHPASTLinterRuleTestCase.php',
    'ArcanistDefaultsConfigurationSource' => 'config/source/ArcanistDefaultsConfigurationSource.php',
    'ArcanistDeprecationXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistDeprecationXHPASTLinterRule.php',
    'ArcanistDeprecationXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistDeprecationXHPASTLinterRuleTestCase.php',
    'ArcanistDictionaryConfigurationSource' => 'config/source/ArcanistDictionaryConfigurationSource.php',
    'ArcanistDiffByteSizeException' => 'exception/ArcanistDiffByteSizeException.php',
    'ArcanistDiffChange' => 'parser/diff/ArcanistDiffChange.php',
    'ArcanistDiffChangeType' => 'parser/diff/ArcanistDiffChangeType.php',
    'ArcanistDiffHunk' => 'parser/diff/ArcanistDiffHunk.php',
    'ArcanistDiffParser' => 'parser/ArcanistDiffParser.php',
    'ArcanistDiffParserTestCase' => 'parser/__tests__/ArcanistDiffParserTestCase.php',
    'ArcanistDiffUtils' => 'difference/ArcanistDiffUtils.php',
    'ArcanistDiffUtilsTestCase' => 'difference/__tests__/ArcanistDiffUtilsTestCase.php',
    'ArcanistDiffVectorNode' => 'difference/ArcanistDiffVectorNode.php',
    'ArcanistDiffVectorTree' => 'difference/ArcanistDiffVectorTree.php',
    'ArcanistDiffWorkflow' => 'workflow/ArcanistDiffWorkflow.php',
    'ArcanistDifferentialCommitMessage' => 'differential/ArcanistDifferentialCommitMessage.php',
    'ArcanistDifferentialCommitMessageParserException' => 'differential/ArcanistDifferentialCommitMessageParserException.php',
    'ArcanistDifferentialDependencyGraph' => 'differential/ArcanistDifferentialDependencyGraph.php',
    'ArcanistDifferentialRevisionHash' => 'differential/constants/ArcanistDifferentialRevisionHash.php',
    'ArcanistDifferentialRevisionStatus' => 'differential/constants/ArcanistDifferentialRevisionStatus.php',
    'ArcanistDoubleQuoteXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistDoubleQuoteXHPASTLinterRule.php',
    'ArcanistDoubleQuoteXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistDoubleQuoteXHPASTLinterRuleTestCase.php',
    'ArcanistDownloadWorkflow' => 'workflow/ArcanistDownloadWorkflow.php',
    'ArcanistDuplicateKeysInArrayXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistDuplicateKeysInArrayXHPASTLinterRule.php',
    'ArcanistDuplicateKeysInArrayXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistDuplicateKeysInArrayXHPASTLinterRuleTestCase.php',
    'ArcanistDuplicateSwitchCaseXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistDuplicateSwitchCaseXHPASTLinterRule.php',
    'ArcanistDuplicateSwitchCaseXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistDuplicateSwitchCaseXHPASTLinterRuleTestCase.php',
    'ArcanistDynamicDefineXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistDynamicDefineXHPASTLinterRule.php',
    'ArcanistDynamicDefineXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistDynamicDefineXHPASTLinterRuleTestCase.php',
    'ArcanistElseIfUsageXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistElseIfUsageXHPASTLinterRule.php',
    'ArcanistElseIfUsageXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistElseIfUsageXHPASTLinterRuleTestCase.php',
    'ArcanistEmptyFileXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistEmptyFileXHPASTLinterRule.php',
    'ArcanistEmptyStatementXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistEmptyStatementXHPASTLinterRule.php',
    'ArcanistEmptyStatementXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistEmptyStatementXHPASTLinterRuleTestCase.php',
    'ArcanistEventType' => 'events/constant/ArcanistEventType.php',
    'ArcanistExitExpressionXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistExitExpressionXHPASTLinterRule.php',
    'ArcanistExitExpressionXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistExitExpressionXHPASTLinterRuleTestCase.php',
    'ArcanistExportWorkflow' => 'workflow/ArcanistExportWorkflow.php',
    'ArcanistExternalLinter' => 'lint/linter/ArcanistExternalLinter.php',
    'ArcanistExternalLinterTestCase' => 'lint/linter/__tests__/ArcanistExternalLinterTestCase.php',
    'ArcanistExtractUseXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistExtractUseXHPASTLinterRule.php',
    'ArcanistExtractUseXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistExtractUseXHPASTLinterRuleTestCase.php',
    'ArcanistFileConfigurationSource' => 'config/source/ArcanistFileConfigurationSource.php',
    'ArcanistFileDataRef' => 'upload/ArcanistFileDataRef.php',
    'ArcanistFileRef' => 'ref/file/ArcanistFileRef.php',
    'ArcanistFileSymbolRef' => 'ref/file/ArcanistFileSymbolRef.php',
    'ArcanistFileUploader' => 'upload/ArcanistFileUploader.php',
    'ArcanistFilenameLinter' => 'lint/linter/ArcanistFilenameLinter.php',
    'ArcanistFilenameLinterTestCase' => 'lint/linter/__tests__/ArcanistFilenameLinterTestCase.php',
    'ArcanistFilesystemAPI' => 'repository/api/ArcanistFilesystemAPI.php',
    'ArcanistFilesystemConfigurationSource' => 'config/source/ArcanistFilesystemConfigurationSource.php',
    'ArcanistFilesystemWorkingCopy' => 'workingcopy/ArcanistFilesystemWorkingCopy.php',
    'ArcanistFlake8Linter' => 'lint/linter/ArcanistFlake8Linter.php',
    'ArcanistFlake8LinterTestCase' => 'lint/linter/__tests__/ArcanistFlake8LinterTestCase.php',
    'ArcanistFormattedStringXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistFormattedStringXHPASTLinterRule.php',
    'ArcanistFormattedStringXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistFormattedStringXHPASTLinterRuleTestCase.php',
    'ArcanistFunctionCallShouldBeTypeCastXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistFunctionCallShouldBeTypeCastXHPASTLinterRule.php',
    'ArcanistFunctionCallShouldBeTypeCastXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistFunctionCallShouldBeTypeCastXHPASTLinterRuleTestCase.php',
    'ArcanistFutureLinter' => 'lint/linter/ArcanistFutureLinter.php',
    'ArcanistGeneratedLinter' => 'lint/linter/ArcanistGeneratedLinter.php',
    'ArcanistGeneratedLinterTestCase' => 'lint/linter/__tests__/ArcanistGeneratedLinterTestCase.php',
    'ArcanistGetConfigWorkflow' => 'workflow/ArcanistGetConfigWorkflow.php',
    'ArcanistGitAPI' => 'repository/api/ArcanistGitAPI.php',
    'ArcanistGitCommitGraphQuery' => 'repository/graph/query/ArcanistGitCommitGraphQuery.php',
    'ArcanistGitCommitMessageHardpointQuery' => 'query/ArcanistGitCommitMessageHardpointQuery.php',
    'ArcanistGitCommitSymbolCommitHardpointQuery' => 'ref/commit/ArcanistGitCommitSymbolCommitHardpointQuery.php',
    'ArcanistGitLandEngine' => 'land/engine/ArcanistGitLandEngine.php',
    'ArcanistGitLocalState' => 'repository/state/ArcanistGitLocalState.php',
    'ArcanistGitRawCommit' => 'repository/raw/ArcanistGitRawCommit.php',
    'ArcanistGitRawCommitTestCase' => 'repository/raw/__tests__/ArcanistGitRawCommitTestCase.php',
    'ArcanistGitRepositoryMarkerQuery' => 'repository/marker/ArcanistGitRepositoryMarkerQuery.php',
    'ArcanistGitRepositoryRemoteQuery' => 'repository/remote/ArcanistGitRepositoryRemoteQuery.php',
    'ArcanistGitUpstreamPath' => 'repository/api/ArcanistGitUpstreamPath.php',
    'ArcanistGitWorkEngine' => 'work/ArcanistGitWorkEngine.php',
    'ArcanistGitWorkingCopy' => 'workingcopy/ArcanistGitWorkingCopy.php',
    'ArcanistGitWorkingCopyRevisionHardpointQuery' => 'query/ArcanistGitWorkingCopyRevisionHardpointQuery.php',
    'ArcanistGlobalVariableXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistGlobalVariableXHPASTLinterRule.php',
    'ArcanistGlobalVariableXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistGlobalVariableXHPASTLinterRuleTestCase.php',
    'ArcanistGoLintLinter' => 'lint/linter/ArcanistGoLintLinter.php',
    'ArcanistGoLintLinterTestCase' => 'lint/linter/__tests__/ArcanistGoLintLinterTestCase.php',
    'ArcanistGoTestResultParser' => 'unit/parser/ArcanistGoTestResultParser.php',
    'ArcanistGoTestResultParserTestCase' => 'unit/parser/__tests__/ArcanistGoTestResultParserTestCase.php',
    'ArcanistGridCell' => 'console/grid/ArcanistGridCell.php',
    'ArcanistGridColumn' => 'console/grid/ArcanistGridColumn.php',
    'ArcanistGridRow' => 'console/grid/ArcanistGridRow.php',
    'ArcanistGridView' => 'console/grid/ArcanistGridView.php',
    'ArcanistHLintLinter' => 'lint/linter/ArcanistHLintLinter.php',
    'ArcanistHLintLinterTestCase' => 'lint/linter/__tests__/ArcanistHLintLinterTestCase.php',
    'ArcanistHardpoint' => 'hardpoint/ArcanistHardpoint.php',
    'ArcanistHardpointEngine' => 'hardpoint/ArcanistHardpointEngine.php',
    'ArcanistHardpointFutureList' => 'hardpoint/ArcanistHardpointFutureList.php',
    'ArcanistHardpointList' => 'hardpoint/ArcanistHardpointList.php',
    'ArcanistHardpointObject' => 'hardpoint/ArcanistHardpointObject.php',
    'ArcanistHardpointQuery' => 'hardpoint/ArcanistHardpointQuery.php',
    'ArcanistHardpointRequest' => 'hardpoint/ArcanistHardpointRequest.php',
    'ArcanistHardpointRequestList' => 'hardpoint/ArcanistHardpointRequestList.php',
    'ArcanistHardpointTask' => 'hardpoint/ArcanistHardpointTask.php',
    'ArcanistHardpointTaskResult' => 'hardpoint/ArcanistHardpointTaskResult.php',
    'ArcanistHelpWorkflow' => 'toolset/workflow/ArcanistHelpWorkflow.php',
    'ArcanistHexadecimalNumericScalarCasingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistHexadecimalNumericScalarCasingXHPASTLinterRule.php',
    'ArcanistHexadecimalNumericScalarCasingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistHexadecimalNumericScalarCasingXHPASTLinterRuleTestCase.php',
    'ArcanistHgClientChannel' => 'hgdaemon/ArcanistHgClientChannel.php',
    'ArcanistHgProxyClient' => 'hgdaemon/ArcanistHgProxyClient.php',
    'ArcanistHgProxyServer' => 'hgdaemon/ArcanistHgProxyServer.php',
    'ArcanistHgServerChannel' => 'hgdaemon/ArcanistHgServerChannel.php',
    'ArcanistImplicitConstructorXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistImplicitConstructorXHPASTLinterRule.php',
    'ArcanistImplicitConstructorXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistImplicitConstructorXHPASTLinterRuleTestCase.php',
    'ArcanistImplicitFallthroughXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistImplicitFallthroughXHPASTLinterRule.php',
    'ArcanistImplicitFallthroughXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistImplicitFallthroughXHPASTLinterRuleTestCase.php',
    'ArcanistImplicitVisibilityXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistImplicitVisibilityXHPASTLinterRule.php',
    'ArcanistImplicitVisibilityXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistImplicitVisibilityXHPASTLinterRuleTestCase.php',
    'ArcanistImplodeArgumentOrderXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistImplodeArgumentOrderXHPASTLinterRule.php',
    'ArcanistImplodeArgumentOrderXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistImplodeArgumentOrderXHPASTLinterRuleTestCase.php',
    'ArcanistInlineHTMLXHPASTLinterRule' => 'lint/linter/ArcanistInlineHTMLXHPASTLinterRule.php',
    'ArcanistInlineHTMLXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistInlineHTMLXHPASTLinterRuleTestCase.php',
    'ArcanistInnerFunctionXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistInnerFunctionXHPASTLinterRule.php',
    'ArcanistInnerFunctionXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistInnerFunctionXHPASTLinterRuleTestCase.php',
    'ArcanistInspectWorkflow' => 'workflow/ArcanistInspectWorkflow.php',
    'ArcanistInstallCertificateWorkflow' => 'workflow/ArcanistInstallCertificateWorkflow.php',
    'ArcanistInstanceOfOperatorXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistInstanceOfOperatorXHPASTLinterRule.php',
    'ArcanistInstanceofOperatorXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistInstanceofOperatorXHPASTLinterRuleTestCase.php',
    'ArcanistInterfaceAbstractMethodXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistInterfaceAbstractMethodXHPASTLinterRule.php',
    'ArcanistInterfaceAbstractMethodXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistInterfaceAbstractMethodXHPASTLinterRuleTestCase.php',
    'ArcanistInterfaceMethodBodyXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistInterfaceMethodBodyXHPASTLinterRule.php',
    'ArcanistInterfaceMethodBodyXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistInterfaceMethodBodyXHPASTLinterRuleTestCase.php',
    'ArcanistInvalidDefaultParameterXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistInvalidDefaultParameterXHPASTLinterRule.php',
    'ArcanistInvalidDefaultParameterXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistInvalidDefaultParameterXHPASTLinterRuleTestCase.php',
    'ArcanistInvalidModifiersXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistInvalidModifiersXHPASTLinterRule.php',
    'ArcanistInvalidModifiersXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistInvalidModifiersXHPASTLinterRuleTestCase.php',
    'ArcanistInvalidOctalNumericScalarXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistInvalidOctalNumericScalarXHPASTLinterRule.php',
    'ArcanistInvalidOctalNumericScalarXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistInvalidOctalNumericScalarXHPASTLinterRuleTestCase.php',
    'ArcanistIsAShouldBeInstanceOfXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistIsAShouldBeInstanceOfXHPASTLinterRule.php',
    'ArcanistIsAShouldBeInstanceOfXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistIsAShouldBeInstanceOfXHPASTLinterRuleTestCase.php',
    'ArcanistJSHintLinter' => 'lint/linter/ArcanistJSHintLinter.php',
    'ArcanistJSHintLinterTestCase' => 'lint/linter/__tests__/ArcanistJSHintLinterTestCase.php',
    'ArcanistJSONLintLinter' => 'lint/linter/ArcanistJSONLintLinter.php',
    'ArcanistJSONLintRenderer' => 'lint/renderer/ArcanistJSONLintRenderer.php',
    'ArcanistJSONLinter' => 'lint/linter/ArcanistJSONLinter.php',
    'ArcanistJSONLinterTestCase' => 'lint/linter/__tests__/ArcanistJSONLinterTestCase.php',
    'ArcanistJscsLinter' => 'lint/linter/ArcanistJscsLinter.php',
    'ArcanistJscsLinterTestCase' => 'lint/linter/__tests__/ArcanistJscsLinterTestCase.php',
    'ArcanistKeywordCasingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistKeywordCasingXHPASTLinterRule.php',
    'ArcanistKeywordCasingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistKeywordCasingXHPASTLinterRuleTestCase.php',
    'ArcanistLambdaFuncFunctionXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistLambdaFuncFunctionXHPASTLinterRule.php',
    'ArcanistLambdaFuncFunctionXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistLambdaFuncFunctionXHPASTLinterRuleTestCase.php',
    'ArcanistLandCommit' => 'land/ArcanistLandCommit.php',
    'ArcanistLandCommitSet' => 'land/ArcanistLandCommitSet.php',
    'ArcanistLandEngine' => 'land/engine/ArcanistLandEngine.php',
    'ArcanistLandPushFailureException' => 'land/exception/ArcanistLandPushFailureException.php',
    'ArcanistLandSymbol' => 'land/ArcanistLandSymbol.php',
    'ArcanistLandTarget' => 'land/ArcanistLandTarget.php',
    'ArcanistLandWorkflow' => 'workflow/ArcanistLandWorkflow.php',
    'ArcanistLanguageConstructParenthesesXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistLanguageConstructParenthesesXHPASTLinterRule.php',
    'ArcanistLanguageConstructParenthesesXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistLanguageConstructParenthesesXHPASTLinterRuleTestCase.php',
    'ArcanistLesscLinter' => 'lint/linter/ArcanistLesscLinter.php',
    'ArcanistLesscLinterTestCase' => 'lint/linter/__tests__/ArcanistLesscLinterTestCase.php',
    'ArcanistLiberateWorkflow' => 'workflow/ArcanistLiberateWorkflow.php',
    'ArcanistLintEngine' => 'lint/engine/ArcanistLintEngine.php',
    'ArcanistLintMessage' => 'lint/ArcanistLintMessage.php',
    'ArcanistLintMessageTestCase' => 'lint/__tests__/ArcanistLintMessageTestCase.php',
    'ArcanistLintPatcher' => 'lint/ArcanistLintPatcher.php',
    'ArcanistLintRenderer' => 'lint/renderer/ArcanistLintRenderer.php',
    'ArcanistLintResult' => 'lint/ArcanistLintResult.php',
    'ArcanistLintSeverity' => 'lint/ArcanistLintSeverity.php',
    'ArcanistLintWorkflow' => 'workflow/ArcanistLintWorkflow.php',
    'ArcanistLinter' => 'lint/linter/ArcanistLinter.php',
    'ArcanistLinterStandard' => 'lint/linter/standards/ArcanistLinterStandard.php',
    'ArcanistLinterStandardTestCase' => 'lint/linter/standards/__tests__/ArcanistLinterStandardTestCase.php',
    'ArcanistLinterTestCase' => 'lint/linter/__tests__/ArcanistLinterTestCase.php',
    'ArcanistLintersWorkflow' => 'workflow/ArcanistLintersWorkflow.php',
    'ArcanistListAssignmentXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistListAssignmentXHPASTLinterRule.php',
    'ArcanistListAssignmentXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistListAssignmentXHPASTLinterRuleTestCase.php',
    'ArcanistListConfigOption' => 'config/option/ArcanistListConfigOption.php',
    'ArcanistListWorkflow' => 'workflow/ArcanistListWorkflow.php',
    'ArcanistLocalConfigurationSource' => 'config/source/ArcanistLocalConfigurationSource.php',
    'ArcanistLogEngine' => 'log/ArcanistLogEngine.php',
    'ArcanistLogMessage' => 'log/ArcanistLogMessage.php',
    'ArcanistLogicalOperatorsXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistLogicalOperatorsXHPASTLinterRule.php',
    'ArcanistLogicalOperatorsXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistLogicalOperatorsXHPASTLinterRuleTestCase.php',
    'ArcanistLookWorkflow' => 'workflow/ArcanistLookWorkflow.php',
    'ArcanistLowercaseFunctionsXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistLowercaseFunctionsXHPASTLinterRule.php',
    'ArcanistLowercaseFunctionsXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistLowercaseFunctionsXHPASTLinterRuleTestCase.php',
    'ArcanistMarkerRef' => 'repository/marker/ArcanistMarkerRef.php',
    'ArcanistMarkersWorkflow' => 'workflow/ArcanistMarkersWorkflow.php',
    'ArcanistMercurialAPI' => 'repository/api/ArcanistMercurialAPI.php',
    'ArcanistMercurialCommitGraphQuery' => 'repository/graph/query/ArcanistMercurialCommitGraphQuery.php',
    'ArcanistMercurialCommitMessageHardpointQuery' => 'query/ArcanistMercurialCommitMessageHardpointQuery.php',
    'ArcanistMercurialLandEngine' => 'land/engine/ArcanistMercurialLandEngine.php',
    'ArcanistMercurialLocalState' => 'repository/state/ArcanistMercurialLocalState.php',
    'ArcanistMercurialParser' => 'repository/parser/ArcanistMercurialParser.php',
    'ArcanistMercurialParserTestCase' => 'repository/parser/__tests__/ArcanistMercurialParserTestCase.php',
    'ArcanistMercurialRepositoryMarkerQuery' => 'repository/marker/ArcanistMercurialRepositoryMarkerQuery.php',
    'ArcanistMercurialRepositoryRemoteQuery' => 'repository/remote/ArcanistMercurialRepositoryRemoteQuery.php',
    'ArcanistMercurialWorkEngine' => 'work/ArcanistMercurialWorkEngine.php',
    'ArcanistMercurialWorkingCopy' => 'workingcopy/ArcanistMercurialWorkingCopy.php',
    'ArcanistMercurialWorkingCopyRevisionHardpointQuery' => 'query/ArcanistMercurialWorkingCopyRevisionHardpointQuery.php',
    'ArcanistMergeConflictLinter' => 'lint/linter/ArcanistMergeConflictLinter.php',
    'ArcanistMergeConflictLinterTestCase' => 'lint/linter/__tests__/ArcanistMergeConflictLinterTestCase.php',
    'ArcanistMessageRevisionHardpointQuery' => 'query/ArcanistMessageRevisionHardpointQuery.php',
    'ArcanistMissingArgumentTerminatorException' => 'exception/ArcanistMissingArgumentTerminatorException.php',
    'ArcanistMissingLinterException' => 'lint/linter/exception/ArcanistMissingLinterException.php',
    'ArcanistModifierOrderingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistModifierOrderingXHPASTLinterRule.php',
    'ArcanistModifierOrderingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistModifierOrderingXHPASTLinterRuleTestCase.php',
    'ArcanistMultiSourceConfigOption' => 'config/option/ArcanistMultiSourceConfigOption.php',
    'ArcanistNamespaceFirstStatementXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistNamespaceFirstStatementXHPASTLinterRule.php',
    'ArcanistNamespaceFirstStatementXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistNamespaceFirstStatementXHPASTLinterRuleTestCase.php',
    'ArcanistNamingConventionsXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistNamingConventionsXHPASTLinterRule.php',
    'ArcanistNamingConventionsXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistNamingConventionsXHPASTLinterRuleTestCase.php',
    'ArcanistNestedNamespacesXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistNestedNamespacesXHPASTLinterRule.php',
    'ArcanistNestedNamespacesXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistNestedNamespacesXHPASTLinterRuleTestCase.php',
    'ArcanistNewlineAfterOpenTagXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistNewlineAfterOpenTagXHPASTLinterRule.php',
    'ArcanistNewlineAfterOpenTagXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistNewlineAfterOpenTagXHPASTLinterRuleTestCase.php',
    'ArcanistNoEffectException' => 'exception/usage/ArcanistNoEffectException.php',
    'ArcanistNoEngineException' => 'exception/usage/ArcanistNoEngineException.php',
    'ArcanistNoLintLinter' => 'lint/linter/ArcanistNoLintLinter.php',
    'ArcanistNoLintLinterTestCase' => 'lint/linter/__tests__/ArcanistNoLintLinterTestCase.php',
    'ArcanistNoParentScopeXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistNoParentScopeXHPASTLinterRule.php',
    'ArcanistNoParentScopeXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistNoParentScopeXHPASTLinterRuleTestCase.php',
    'ArcanistNoURIConduitException' => 'conduit/ArcanistNoURIConduitException.php',
    'ArcanistNoneLintRenderer' => 'lint/renderer/ArcanistNoneLintRenderer.php',
    'ArcanistObjectListHardpoint' => 'hardpoint/ArcanistObjectListHardpoint.php',
    'ArcanistObjectOperatorSpacingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistObjectOperatorSpacingXHPASTLinterRule.php',
    'ArcanistObjectOperatorSpacingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistObjectOperatorSpacingXHPASTLinterRuleTestCase.php',
    'ArcanistPEP8Linter' => 'lint/linter/ArcanistPEP8Linter.php',
    'ArcanistPEP8LinterTestCase' => 'lint/linter/__tests__/ArcanistPEP8LinterTestCase.php',
    'ArcanistPHPCloseTagXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistPHPCloseTagXHPASTLinterRule.php',
    'ArcanistPHPCloseTagXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistPHPCloseTagXHPASTLinterRuleTestCase.php',
    'ArcanistPHPCompatibilityXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistPHPCompatibilityXHPASTLinterRule.php',
    'ArcanistPHPCompatibilityXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistPHPCompatibilityXHPASTLinterRuleTestCase.php',
    'ArcanistPHPEchoTagXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistPHPEchoTagXHPASTLinterRule.php',
    'ArcanistPHPEchoTagXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistPHPEchoTagXHPASTLinterRuleTestCase.php',
    'ArcanistPHPOpenTagXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistPHPOpenTagXHPASTLinterRule.php',
    'ArcanistPHPOpenTagXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistPHPOpenTagXHPASTLinterRuleTestCase.php',
    'ArcanistPHPShortTagXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistPHPShortTagXHPASTLinterRule.php',
    'ArcanistPHPShortTagXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistPHPShortTagXHPASTLinterRuleTestCase.php',
    'ArcanistPaamayimNekudotayimSpacingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistPaamayimNekudotayimSpacingXHPASTLinterRule.php',
    'ArcanistPaamayimNekudotayimSpacingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistPaamayimNekudotayimSpacingXHPASTLinterRuleTestCase.php',
    'ArcanistParentMemberReferenceXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistParentMemberReferenceXHPASTLinterRule.php',
    'ArcanistParentMemberReferenceXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistParentMemberReferenceXHPASTLinterRuleTestCase.php',
    'ArcanistParenthesesSpacingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistParenthesesSpacingXHPASTLinterRule.php',
    'ArcanistParenthesesSpacingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistParenthesesSpacingXHPASTLinterRuleTestCase.php',
    'ArcanistParseStrUseXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistParseStrUseXHPASTLinterRule.php',
    'ArcanistParseStrUseXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistParseStrUseXHPASTLinterRuleTestCase.php',
    'ArcanistPasteRef' => 'ref/paste/ArcanistPasteRef.php',
    'ArcanistPasteSymbolRef' => 'ref/paste/ArcanistPasteSymbolRef.php',
    'ArcanistPasteWorkflow' => 'workflow/ArcanistPasteWorkflow.php',
    'ArcanistPatchWorkflow' => 'workflow/ArcanistPatchWorkflow.php',
    'ArcanistPhpLinter' => 'lint/linter/ArcanistPhpLinter.php',
    'ArcanistPhpLinterTestCase' => 'lint/linter/__tests__/ArcanistPhpLinterTestCase.php',
    'ArcanistPhpcsLinter' => 'lint/linter/ArcanistPhpcsLinter.php',
    'ArcanistPhpcsLinterTestCase' => 'lint/linter/__tests__/ArcanistPhpcsLinterTestCase.php',
    'ArcanistPhpunitTestResultParser' => 'unit/parser/ArcanistPhpunitTestResultParser.php',
    'ArcanistPhutilLibraryLinter' => 'lint/linter/ArcanistPhutilLibraryLinter.php',
    'ArcanistPhutilWorkflow' => 'toolset/ArcanistPhutilWorkflow.php',
    'ArcanistPhutilXHPASTLinterStandard' => 'lint/linter/standards/phutil/ArcanistPhutilXHPASTLinterStandard.php',
    'ArcanistPlusOperatorOnStringsXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistPlusOperatorOnStringsXHPASTLinterRule.php',
    'ArcanistPlusOperatorOnStringsXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistPlusOperatorOnStringsXHPASTLinterRuleTestCase.php',
    'ArcanistProjectConfigurationSource' => 'config/source/ArcanistProjectConfigurationSource.php',
    'ArcanistPrompt' => 'toolset/ArcanistPrompt.php',
    'ArcanistPromptResponse' => 'toolset/ArcanistPromptResponse.php',
    'ArcanistPromptsConfigOption' => 'config/option/ArcanistPromptsConfigOption.php',
    'ArcanistPromptsWorkflow' => 'toolset/workflow/ArcanistPromptsWorkflow.php',
    'ArcanistPublicPropertyXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistPublicPropertyXHPASTLinterRule.php',
    'ArcanistPublicPropertyXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistPublicPropertyXHPASTLinterRuleTestCase.php',
    'ArcanistPuppetLintLinter' => 'lint/linter/ArcanistPuppetLintLinter.php',
    'ArcanistPuppetLintLinterTestCase' => 'lint/linter/__tests__/ArcanistPuppetLintLinterTestCase.php',
    'ArcanistPyFlakesLinter' => 'lint/linter/ArcanistPyFlakesLinter.php',
    'ArcanistPyFlakesLinterTestCase' => 'lint/linter/__tests__/ArcanistPyFlakesLinterTestCase.php',
    'ArcanistPyLintLinter' => 'lint/linter/ArcanistPyLintLinter.php',
    'ArcanistPyLintLinterTestCase' => 'lint/linter/__tests__/ArcanistPyLintLinterTestCase.php',
    'ArcanistRaggedClassTreeEdgeXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistRaggedClassTreeEdgeXHPASTLinterRule.php',
    'ArcanistRaggedClassTreeEdgeXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistRaggedClassTreeEdgeXHPASTLinterRuleTestCase.php',
    'ArcanistRef' => 'ref/ArcanistRef.php',
    'ArcanistRefInspector' => 'inspector/ArcanistRefInspector.php',
    'ArcanistRefView' => 'ref/ArcanistRefView.php',
    'ArcanistRemoteRef' => 'repository/remote/ArcanistRemoteRef.php',
    'ArcanistRemoteRefInspector' => 'repository/remote/ArcanistRemoteRefInspector.php',
    'ArcanistRemoteRepositoryRefsHardpointQuery' => 'repository/remote/ArcanistRemoteRepositoryRefsHardpointQuery.php',
    'ArcanistRepositoryAPI' => 'repository/api/ArcanistRepositoryAPI.php',
    'ArcanistRepositoryAPIMiscTestCase' => 'repository/api/__tests__/ArcanistRepositoryAPIMiscTestCase.php',
    'ArcanistRepositoryAPIStateTestCase' => 'repository/api/__tests__/ArcanistRepositoryAPIStateTestCase.php',
    'ArcanistRepositoryLocalState' => 'repository/state/ArcanistRepositoryLocalState.php',
    'ArcanistRepositoryMarkerQuery' => 'repository/marker/ArcanistRepositoryMarkerQuery.php',
    'ArcanistRepositoryQuery' => 'repository/query/ArcanistRepositoryQuery.php',
    'ArcanistRepositoryRef' => 'ref/ArcanistRepositoryRef.php',
    'ArcanistRepositoryRemoteQuery' => 'repository/remote/ArcanistRepositoryRemoteQuery.php',
    'ArcanistRepositoryURINormalizer' => 'repository/remote/ArcanistRepositoryURINormalizer.php',
    'ArcanistRepositoryURINormalizerTestCase' => 'repository/remote/__tests__/ArcanistRepositoryURINormalizerTestCase.php',
    'ArcanistReusedAsIteratorXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistReusedAsIteratorXHPASTLinterRule.php',
    'ArcanistReusedAsIteratorXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistReusedAsIteratorXHPASTLinterRuleTestCase.php',
    'ArcanistReusedIteratorReferenceXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistReusedIteratorReferenceXHPASTLinterRule.php',
    'ArcanistReusedIteratorReferenceXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistReusedIteratorReferenceXHPASTLinterRuleTestCase.php',
    'ArcanistReusedIteratorXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistReusedIteratorXHPASTLinterRule.php',
    'ArcanistReusedIteratorXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistReusedIteratorXHPASTLinterRuleTestCase.php',
    'ArcanistRevisionAuthorHardpointQuery' => 'ref/revision/ArcanistRevisionAuthorHardpointQuery.php',
    'ArcanistRevisionBuildableHardpointQuery' => 'ref/revision/ArcanistRevisionBuildableHardpointQuery.php',
    'ArcanistRevisionCommitMessageHardpointQuery' => 'ref/revision/ArcanistRevisionCommitMessageHardpointQuery.php',
    'ArcanistRevisionParentRevisionsHardpointQuery' => 'ref/revision/ArcanistRevisionParentRevisionsHardpointQuery.php',
    'ArcanistRevisionRef' => 'ref/revision/ArcanistRevisionRef.php',
    'ArcanistRevisionRefSource' => 'ref/ArcanistRevisionRefSource.php',
    'ArcanistRevisionSymbolRef' => 'ref/revision/ArcanistRevisionSymbolRef.php',
    'ArcanistRuboCopLinter' => 'lint/linter/ArcanistRuboCopLinter.php',
    'ArcanistRuboCopLinterTestCase' => 'lint/linter/__tests__/ArcanistRuboCopLinterTestCase.php',
    'ArcanistRubyLinter' => 'lint/linter/ArcanistRubyLinter.php',
    'ArcanistRubyLinterTestCase' => 'lint/linter/__tests__/ArcanistRubyLinterTestCase.php',
    'ArcanistRuntime' => 'runtime/ArcanistRuntime.php',
    'ArcanistRuntimeConfigurationSource' => 'config/source/ArcanistRuntimeConfigurationSource.php',
    'ArcanistRuntimeHardpointQuery' => 'toolset/query/ArcanistRuntimeHardpointQuery.php',
    'ArcanistScalarHardpoint' => 'hardpoint/ArcanistScalarHardpoint.php',
    'ArcanistScriptAndRegexLinter' => 'lint/linter/ArcanistScriptAndRegexLinter.php',
    'ArcanistSelfClassReferenceXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistSelfClassReferenceXHPASTLinterRule.php',
    'ArcanistSelfClassReferenceXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistSelfClassReferenceXHPASTLinterRuleTestCase.php',
    'ArcanistSelfMemberReferenceXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistSelfMemberReferenceXHPASTLinterRule.php',
    'ArcanistSelfMemberReferenceXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistSelfMemberReferenceXHPASTLinterRuleTestCase.php',
    'ArcanistSemicolonSpacingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistSemicolonSpacingXHPASTLinterRule.php',
    'ArcanistSemicolonSpacingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistSemicolonSpacingXHPASTLinterRuleTestCase.php',
    'ArcanistSetConfigWorkflow' => 'workflow/ArcanistSetConfigWorkflow.php',
    'ArcanistSetting' => 'configuration/ArcanistSetting.php',
    'ArcanistSettings' => 'configuration/ArcanistSettings.php',
    'ArcanistShellCompleteWorkflow' => 'toolset/workflow/ArcanistShellCompleteWorkflow.php',
    'ArcanistSimpleCommitGraphQuery' => 'repository/graph/query/ArcanistSimpleCommitGraphQuery.php',
    'ArcanistSimpleSymbolHardpointQuery' => 'ref/simple/ArcanistSimpleSymbolHardpointQuery.php',
    'ArcanistSimpleSymbolRef' => 'ref/simple/ArcanistSimpleSymbolRef.php',
    'ArcanistSimpleSymbolRefInspector' => 'ref/simple/ArcanistSimpleSymbolRefInspector.php',
    'ArcanistSingleLintEngine' => 'lint/engine/ArcanistSingleLintEngine.php',
    'ArcanistSingleSourceConfigOption' => 'config/option/ArcanistSingleSourceConfigOption.php',
    'ArcanistSlownessXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistSlownessXHPASTLinterRule.php',
    'ArcanistSlownessXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistSlownessXHPASTLinterRuleTestCase.php',
    'ArcanistSpellingLinter' => 'lint/linter/ArcanistSpellingLinter.php',
    'ArcanistSpellingLinterTestCase' => 'lint/linter/__tests__/ArcanistSpellingLinterTestCase.php',
    'ArcanistStaticThisXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistStaticThisXHPASTLinterRule.php',
    'ArcanistStaticThisXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistStaticThisXHPASTLinterRuleTestCase.php',
    'ArcanistStringConfigOption' => 'config/option/ArcanistStringConfigOption.php',
    'ArcanistStringListConfigOption' => 'config/option/ArcanistStringListConfigOption.php',
    'ArcanistSubversionAPI' => 'repository/api/ArcanistSubversionAPI.php',
    'ArcanistSubversionWorkingCopy' => 'workingcopy/ArcanistSubversionWorkingCopy.php',
    'ArcanistSummaryLintRenderer' => 'lint/renderer/ArcanistSummaryLintRenderer.php',
    'ArcanistSymbolEngine' => 'ref/symbol/ArcanistSymbolEngine.php',
    'ArcanistSymbolRef' => 'ref/symbol/ArcanistSymbolRef.php',
    'ArcanistSyntaxErrorXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistSyntaxErrorXHPASTLinterRule.php',
    'ArcanistSystemConfigurationSource' => 'config/source/ArcanistSystemConfigurationSource.php',
    'ArcanistTaskRef' => 'ref/task/ArcanistTaskRef.php',
    'ArcanistTaskSymbolRef' => 'ref/task/ArcanistTaskSymbolRef.php',
    'ArcanistTasksWorkflow' => 'workflow/ArcanistTasksWorkflow.php',
    'ArcanistTautologicalExpressionXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistTautologicalExpressionXHPASTLinterRule.php',
    'ArcanistTautologicalExpressionXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistTautologicalExpressionXHPASTLinterRuleTestCase.php',
    'ArcanistTerminalStringInterface' => 'xsprintf/ArcanistTerminalStringInterface.php',
    'ArcanistTestResultParser' => 'unit/parser/ArcanistTestResultParser.php',
    'ArcanistTestXHPASTLintSwitchHook' => 'lint/linter/__tests__/ArcanistTestXHPASTLintSwitchHook.php',
    'ArcanistTextLinter' => 'lint/linter/ArcanistTextLinter.php',
    'ArcanistTextLinterTestCase' => 'lint/linter/__tests__/ArcanistTextLinterTestCase.php',
    'ArcanistThisReassignmentXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistThisReassignmentXHPASTLinterRule.php',
    'ArcanistThisReassignmentXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistThisReassignmentXHPASTLinterRuleTestCase.php',
    'ArcanistToStringExceptionXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistToStringExceptionXHPASTLinterRule.php',
    'ArcanistToStringExceptionXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistToStringExceptionXHPASTLinterRuleTestCase.php',
    'ArcanistTodoCommentXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistTodoCommentXHPASTLinterRule.php',
    'ArcanistTodoCommentXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistTodoCommentXHPASTLinterRuleTestCase.php',
    'ArcanistTodoWorkflow' => 'workflow/ArcanistTodoWorkflow.php',
    'ArcanistToolset' => 'toolset/ArcanistToolset.php',
    'ArcanistUSEnglishTranslation' => 'internationalization/ArcanistUSEnglishTranslation.php',
    'ArcanistUnableToParseXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistUnableToParseXHPASTLinterRule.php',
    'ArcanistUnaryPostfixExpressionSpacingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistUnaryPostfixExpressionSpacingXHPASTLinterRule.php',
    'ArcanistUnaryPostfixExpressionSpacingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistUnaryPostfixExpressionSpacingXHPASTLinterRuleTestCase.php',
    'ArcanistUnaryPrefixExpressionSpacingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistUnaryPrefixExpressionSpacingXHPASTLinterRule.php',
    'ArcanistUnaryPrefixExpressionSpacingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistUnaryPrefixExpressionSpacingXHPASTLinterRuleTestCase.php',
    'ArcanistUndeclaredVariableXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistUndeclaredVariableXHPASTLinterRule.php',
    'ArcanistUndeclaredVariableXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistUndeclaredVariableXHPASTLinterRuleTestCase.php',
    'ArcanistUnexpectedReturnValueXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistUnexpectedReturnValueXHPASTLinterRule.php',
    'ArcanistUnexpectedReturnValueXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistUnexpectedReturnValueXHPASTLinterRuleTestCase.php',
    'ArcanistUnitConsoleRenderer' => 'unit/renderer/ArcanistUnitConsoleRenderer.php',
    'ArcanistUnitRenderer' => 'unit/renderer/ArcanistUnitRenderer.php',
    'ArcanistUnitTestEngine' => 'unit/engine/ArcanistUnitTestEngine.php',
    'ArcanistUnitTestResult' => 'unit/ArcanistUnitTestResult.php',
    'ArcanistUnitTestResultTestCase' => 'unit/__tests__/ArcanistUnitTestResultTestCase.php',
    'ArcanistUnitTestableLintEngine' => 'lint/engine/ArcanistUnitTestableLintEngine.php',
    'ArcanistUnitWorkflow' => 'workflow/ArcanistUnitWorkflow.php',
    'ArcanistUnnecessaryFinalModifierXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistUnnecessaryFinalModifierXHPASTLinterRule.php',
    'ArcanistUnnecessaryFinalModifierXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistUnnecessaryFinalModifierXHPASTLinterRuleTestCase.php',
    'ArcanistUnnecessarySemicolonXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistUnnecessarySemicolonXHPASTLinterRule.php',
    'ArcanistUnnecessarySymbolAliasXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistUnnecessarySymbolAliasXHPASTLinterRule.php',
    'ArcanistUnnecessarySymbolAliasXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistUnnecessarySymbolAliasXHPASTLinterRuleTestCase.php',
    'ArcanistUnsafeDynamicStringXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistUnsafeDynamicStringXHPASTLinterRule.php',
    'ArcanistUnsafeDynamicStringXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistUnsafeDynamicStringXHPASTLinterRuleTestCase.php',
    'ArcanistUpgradeWorkflow' => 'workflow/ArcanistUpgradeWorkflow.php',
    'ArcanistUploadWorkflow' => 'workflow/ArcanistUploadWorkflow.php',
    'ArcanistUsageException' => 'exception/ArcanistUsageException.php',
    'ArcanistUseStatementNamespacePrefixXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistUseStatementNamespacePrefixXHPASTLinterRule.php',
    'ArcanistUseStatementNamespacePrefixXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistUseStatementNamespacePrefixXHPASTLinterRuleTestCase.php',
    'ArcanistUselessOverridingMethodXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistUselessOverridingMethodXHPASTLinterRule.php',
    'ArcanistUselessOverridingMethodXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistUselessOverridingMethodXHPASTLinterRuleTestCase.php',
    'ArcanistUserAbortException' => 'exception/usage/ArcanistUserAbortException.php',
    'ArcanistUserConfigurationSource' => 'config/source/ArcanistUserConfigurationSource.php',
    'ArcanistUserRef' => 'ref/user/ArcanistUserRef.php',
    'ArcanistUserSymbolHardpointQuery' => 'ref/user/ArcanistUserSymbolHardpointQuery.php',
    'ArcanistUserSymbolRef' => 'ref/user/ArcanistUserSymbolRef.php',
    'ArcanistUserSymbolRefInspector' => 'ref/user/ArcanistUserSymbolRefInspector.php',
    'ArcanistVariableReferenceSpacingXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistVariableReferenceSpacingXHPASTLinterRule.php',
    'ArcanistVariableReferenceSpacingXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistVariableReferenceSpacingXHPASTLinterRuleTestCase.php',
    'ArcanistVariableVariableXHPASTLinterRule' => 'lint/linter/xhpast/rules/ArcanistVariableVariableXHPASTLinterRule.php',
    'ArcanistVariableVariableXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistVariableVariableXHPASTLinterRuleTestCase.php',
    'ArcanistVectorHardpoint' => 'hardpoint/ArcanistVectorHardpoint.php',
    'ArcanistVersionWorkflow' => 'toolset/workflow/ArcanistVersionWorkflow.php',
    'ArcanistWeldWorkflow' => 'workflow/ArcanistWeldWorkflow.php',
    'ArcanistWhichWorkflow' => 'workflow/ArcanistWhichWorkflow.php',
    'ArcanistWildConfigOption' => 'config/option/ArcanistWildConfigOption.php',
    'ArcanistWorkEngine' => 'work/ArcanistWorkEngine.php',
    'ArcanistWorkWorkflow' => 'workflow/ArcanistWorkWorkflow.php',
    'ArcanistWorkflow' => 'workflow/ArcanistWorkflow.php',
    'ArcanistWorkflowArgument' => 'toolset/ArcanistWorkflowArgument.php',
    'ArcanistWorkflowEngine' => 'engine/ArcanistWorkflowEngine.php',
    'ArcanistWorkflowGitHardpointQuery' => 'query/ArcanistWorkflowGitHardpointQuery.php',
    'ArcanistWorkflowInformation' => 'toolset/ArcanistWorkflowInformation.php',
    'ArcanistWorkflowMercurialHardpointQuery' => 'query/ArcanistWorkflowMercurialHardpointQuery.php',
    'ArcanistWorkingCopy' => 'workingcopy/ArcanistWorkingCopy.php',
    'ArcanistWorkingCopyConfigurationSource' => 'config/source/ArcanistWorkingCopyConfigurationSource.php',
    'ArcanistWorkingCopyIdentity' => 'workingcopyidentity/ArcanistWorkingCopyIdentity.php',
    'ArcanistWorkingCopyPath' => 'workingcopy/ArcanistWorkingCopyPath.php',
    'ArcanistWorkingCopyStateRef' => 'ref/ArcanistWorkingCopyStateRef.php',
    'ArcanistWorkingCopyStateRefInspector' => 'inspector/ArcanistWorkingCopyStateRefInspector.php',
    'ArcanistXHPASTLintNamingHook' => 'lint/linter/xhpast/ArcanistXHPASTLintNamingHook.php',
    'ArcanistXHPASTLintNamingHookTestCase' => 'lint/linter/xhpast/__tests__/ArcanistXHPASTLintNamingHookTestCase.php',
    'ArcanistXHPASTLintSwitchHook' => 'lint/linter/xhpast/ArcanistXHPASTLintSwitchHook.php',
    'ArcanistXHPASTLinter' => 'lint/linter/ArcanistXHPASTLinter.php',
    'ArcanistXHPASTLinterRule' => 'lint/linter/xhpast/ArcanistXHPASTLinterRule.php',
    'ArcanistXHPASTLinterRuleTestCase' => 'lint/linter/xhpast/rules/__tests__/ArcanistXHPASTLinterRuleTestCase.php',
    'ArcanistXHPASTLinterTestCase' => 'lint/linter/__tests__/ArcanistXHPASTLinterTestCase.php',
    'ArcanistXMLLinter' => 'lint/linter/ArcanistXMLLinter.php',
    'ArcanistXMLLinterTestCase' => 'lint/linter/__tests__/ArcanistXMLLinterTestCase.php',
    'ArcanistXUnitTestResultParser' => 'unit/parser/ArcanistXUnitTestResultParser.php',
    'BaseHTTPFuture' => 'future/http/BaseHTTPFuture.php',
    'CSharpToolsTestEngine' => 'unit/engine/CSharpToolsTestEngine.php',
    'CaseInsensitiveArray' => 'utils/CaseInsensitiveArray.php',
    'CaseInsensitiveArrayTestCase' => 'utils/__tests__/CaseInsensitiveArrayTestCase.php',
    'CommandException' => 'future/exec/CommandException.php',
    'ConduitClient' => 'conduit/ConduitClient.php',
    'ConduitClientException' => 'conduit/ConduitClientException.php',
    'ConduitClientTestCase' => 'conduit/__tests__/ConduitClientTestCase.php',
    'ConduitFuture' => 'conduit/ConduitFuture.php',
    'ConduitSearchFuture' => 'conduit/ConduitSearchFuture.php',
    'ExecFuture' => 'future/exec/ExecFuture.php',
    'ExecFutureTestCase' => 'future/exec/__tests__/ExecFutureTestCase.php',
    'ExecPassthruTestCase' => 'future/exec/__tests__/ExecPassthruTestCase.php',
    'FileFinder' => 'filesystem/FileFinder.php',
    'FileFinderTestCase' => 'filesystem/__tests__/FileFinderTestCase.php',
    'FileList' => 'filesystem/FileList.php',
    'Filesystem' => 'filesystem/Filesystem.php',
    'FilesystemException' => 'filesystem/FilesystemException.php',
    'FilesystemTestCase' => 'filesystem/__tests__/FilesystemTestCase.php',
    'Future' => 'future/Future.php',
    'FutureAgent' => 'conduit/FutureAgent.php',
    'FutureIterator' => 'future/FutureIterator.php',
    'FutureIteratorTestCase' => 'future/__tests__/FutureIteratorTestCase.php',
    'FuturePool' => 'future/FuturePool.php',
    'FutureProxy' => 'future/FutureProxy.php',
    'HTTPFuture' => 'future/http/HTTPFuture.php',
    'HTTPFutureCURLResponseStatus' => 'future/http/status/HTTPFutureCURLResponseStatus.php',
    'HTTPFutureCertificateResponseStatus' => 'future/http/status/HTTPFutureCertificateResponseStatus.php',
    'HTTPFutureHTTPResponseStatus' => 'future/http/status/HTTPFutureHTTPResponseStatus.php',
    'HTTPFutureParseResponseStatus' => 'future/http/status/HTTPFutureParseResponseStatus.php',
    'HTTPFutureResponseStatus' => 'future/http/status/HTTPFutureResponseStatus.php',
    'HTTPFutureTransportResponseStatus' => 'future/http/status/HTTPFutureTransportResponseStatus.php',
    'HTTPSFuture' => 'future/http/HTTPSFuture.php',
    'ImmediateFuture' => 'future/ImmediateFuture.php',
    'LibphutilUSEnglishTranslation' => 'internationalization/translation/LibphutilUSEnglishTranslation.php',
    'LinesOfALarge' => 'filesystem/linesofalarge/LinesOfALarge.php',
    'LinesOfALargeExecFuture' => 'filesystem/linesofalarge/LinesOfALargeExecFuture.php',
    'LinesOfALargeExecFutureTestCase' => 'filesystem/linesofalarge/__tests__/LinesOfALargeExecFutureTestCase.php',
    'LinesOfALargeFile' => 'filesystem/linesofalarge/LinesOfALargeFile.php',
    'LinesOfALargeFileTestCase' => 'filesystem/linesofalarge/__tests__/LinesOfALargeFileTestCase.php',
    'MFilterTestHelper' => 'utils/__tests__/MFilterTestHelper.php',
    'NoseTestEngine' => 'unit/engine/NoseTestEngine.php',
    'PHPASTParserTestCase' => 'parser/xhpast/__tests__/PHPASTParserTestCase.php',
    'PhageAction' => 'phage/action/PhageAction.php',
    'PhageAgentAction' => 'phage/action/PhageAgentAction.php',
    'PhageAgentBootloader' => 'phage/bootloader/PhageAgentBootloader.php',
    'PhageAgentTestCase' => 'phage/__tests__/PhageAgentTestCase.php',
    'PhageExecWorkflow' => 'phage/workflow/PhageExecWorkflow.php',
    'PhageExecuteAction' => 'phage/action/PhageExecuteAction.php',
    'PhageLocalAction' => 'phage/action/PhageLocalAction.php',
    'PhagePHPAgent' => 'phage/agent/PhagePHPAgent.php',
    'PhagePHPAgentBootloader' => 'phage/bootloader/PhagePHPAgentBootloader.php',
    'PhagePlanAction' => 'phage/action/PhagePlanAction.php',
    'PhageToolset' => 'phage/toolset/PhageToolset.php',
    'PhageWorkflow' => 'phage/workflow/PhageWorkflow.php',
    'Phobject' => 'object/Phobject.php',
    'PhobjectTestCase' => 'object/__tests__/PhobjectTestCase.php',
    'PhpunitTestEngine' => 'unit/engine/PhpunitTestEngine.php',
    'PhpunitTestEngineTestCase' => 'unit/engine/__tests__/PhpunitTestEngineTestCase.php',
    'PhutilAWSCloudFormationFuture' => 'future/aws/PhutilAWSCloudFormationFuture.php',
    'PhutilAWSCloudWatchFuture' => 'future/aws/PhutilAWSCloudWatchFuture.php',
    'PhutilAWSEC2Future' => 'future/aws/PhutilAWSEC2Future.php',
    'PhutilAWSException' => 'future/aws/PhutilAWSException.php',
    'PhutilAWSFuture' => 'future/aws/PhutilAWSFuture.php',
    'PhutilAWSManagementWorkflow' => 'future/aws/management/PhutilAWSManagementWorkflow.php',
    'PhutilAWSS3DeleteManagementWorkflow' => 'future/aws/management/PhutilAWSS3DeleteManagementWorkflow.php',
    'PhutilAWSS3Future' => 'future/aws/PhutilAWSS3Future.php',
    'PhutilAWSS3GetManagementWorkflow' => 'future/aws/management/PhutilAWSS3GetManagementWorkflow.php',
    'PhutilAWSS3ManagementWorkflow' => 'future/aws/management/PhutilAWSS3ManagementWorkflow.php',
    'PhutilAWSS3PutManagementWorkflow' => 'future/aws/management/PhutilAWSS3PutManagementWorkflow.php',
    'PhutilAWSv4Signature' => 'future/aws/PhutilAWSv4Signature.php',
    'PhutilAWSv4SignatureTestCase' => 'future/aws/__tests__/PhutilAWSv4SignatureTestCase.php',
    'PhutilAggregateException' => 'error/PhutilAggregateException.php',
    'PhutilAllCapsEnglishLocale' => 'internationalization/locales/PhutilAllCapsEnglishLocale.php',
    'PhutilArgumentParser' => 'parser/argument/PhutilArgumentParser.php',
    'PhutilArgumentParserException' => 'parser/argument/exception/PhutilArgumentParserException.php',
    'PhutilArgumentParserTestCase' => 'parser/argument/__tests__/PhutilArgumentParserTestCase.php',
    'PhutilArgumentSpecification' => 'parser/argument/PhutilArgumentSpecification.php',
    'PhutilArgumentSpecificationException' => 'parser/argument/exception/PhutilArgumentSpecificationException.php',
    'PhutilArgumentSpecificationTestCase' => 'parser/argument/__tests__/PhutilArgumentSpecificationTestCase.php',
    'PhutilArgumentSpellingCorrector' => 'parser/argument/PhutilArgumentSpellingCorrector.php',
    'PhutilArgumentSpellingCorrectorTestCase' => 'parser/argument/__tests__/PhutilArgumentSpellingCorrectorTestCase.php',
    'PhutilArgumentUsageException' => 'parser/argument/exception/PhutilArgumentUsageException.php',
    'PhutilArgumentWorkflow' => 'parser/argument/workflow/PhutilArgumentWorkflow.php',
    'PhutilArray' => 'utils/PhutilArray.php',
    'PhutilArrayCheck' => 'utils/PhutilArrayCheck.php',
    'PhutilArrayTestCase' => 'utils/__tests__/PhutilArrayTestCase.php',
    'PhutilArrayWithDefaultValue' => 'utils/PhutilArrayWithDefaultValue.php',
    'PhutilAsanaFuture' => 'future/asana/PhutilAsanaFuture.php',
    'PhutilBacktraceSignalHandler' => 'future/exec/PhutilBacktraceSignalHandler.php',
    'PhutilBallOfPHP' => 'phage/util/PhutilBallOfPHP.php',
    'PhutilBinaryAnalyzer' => 'filesystem/binary/PhutilBinaryAnalyzer.php',
    'PhutilBinaryAnalyzerTestCase' => 'filesystem/binary/__tests__/PhutilBinaryAnalyzerTestCase.php',
    'PhutilBootloader' => 'init/lib/PhutilBootloader.php',
    'PhutilBootloaderException' => 'init/lib/PhutilBootloaderException.php',
    'PhutilBritishEnglishLocale' => 'internationalization/locales/PhutilBritishEnglishLocale.php',
    'PhutilBufferedIterator' => 'utils/PhutilBufferedIterator.php',
    'PhutilBufferedIteratorTestCase' => 'utils/__tests__/PhutilBufferedIteratorTestCase.php',
    'PhutilBugtraqParser' => 'parser/PhutilBugtraqParser.php',
    'PhutilBugtraqParserTestCase' => 'parser/__tests__/PhutilBugtraqParserTestCase.php',
    'PhutilCIDRBlock' => 'ip/PhutilCIDRBlock.php',
    'PhutilCIDRList' => 'ip/PhutilCIDRList.php',
    'PhutilCallbackFilterIterator' => 'utils/PhutilCallbackFilterIterator.php',
    'PhutilCallbackSignalHandler' => 'future/exec/PhutilCallbackSignalHandler.php',
    'PhutilChannel' => 'channel/PhutilChannel.php',
    'PhutilChannelChannel' => 'channel/PhutilChannelChannel.php',
    'PhutilChannelTestCase' => 'channel/__tests__/PhutilChannelTestCase.php',
    'PhutilChunkedIterator' => 'utils/PhutilChunkedIterator.php',
    'PhutilChunkedIteratorTestCase' => 'utils/__tests__/PhutilChunkedIteratorTestCase.php',
    'PhutilClassMapQuery' => 'symbols/PhutilClassMapQuery.php',
    'PhutilCloudWatchMetric' => 'future/aws/PhutilCloudWatchMetric.php',
    'PhutilCommandString' => 'xsprintf/PhutilCommandString.php',
    'PhutilConsole' => 'console/PhutilConsole.php',
    'PhutilConsoleBlock' => 'console/view/PhutilConsoleBlock.php',
    'PhutilConsoleError' => 'console/view/PhutilConsoleError.php',
    'PhutilConsoleFormatter' => 'console/PhutilConsoleFormatter.php',
    'PhutilConsoleInfo' => 'console/view/PhutilConsoleInfo.php',
    'PhutilConsoleList' => 'console/view/PhutilConsoleList.php',
    'PhutilConsoleLogLine' => 'console/view/PhutilConsoleLogLine.php',
    'PhutilConsoleMessage' => 'console/PhutilConsoleMessage.php',
    'PhutilConsoleMetrics' => 'console/PhutilConsoleMetrics.php',
    'PhutilConsoleMetricsSignalHandler' => 'future/exec/PhutilConsoleMetricsSignalHandler.php',
    'PhutilConsoleProgressBar' => 'console/PhutilConsoleProgressBar.php',
    'PhutilConsoleProgressSink' => 'progress/PhutilConsoleProgressSink.php',
    'PhutilConsoleServer' => 'console/PhutilConsoleServer.php',
    'PhutilConsoleServerChannel' => 'console/PhutilConsoleServerChannel.php',
    'PhutilConsoleSkip' => 'console/view/PhutilConsoleSkip.php',
    'PhutilConsoleStdinNotInteractiveException' => 'console/PhutilConsoleStdinNotInteractiveException.php',
    'PhutilConsoleTable' => 'console/view/PhutilConsoleTable.php',
    'PhutilConsoleView' => 'console/view/PhutilConsoleView.php',
    'PhutilConsoleWarning' => 'console/view/PhutilConsoleWarning.php',
    'PhutilConsoleWrapTestCase' => 'console/__tests__/PhutilConsoleWrapTestCase.php',
    'PhutilCowsay' => 'utils/PhutilCowsay.php',
    'PhutilCowsayTestCase' => 'utils/__tests__/PhutilCowsayTestCase.php',
    'PhutilCsprintfTestCase' => 'xsprintf/__tests__/PhutilCsprintfTestCase.php',
    'PhutilCzechLocale' => 'internationalization/locales/PhutilCzechLocale.php',
    'PhutilDOMNode' => 'parser/html/PhutilDOMNode.php',
    'PhutilDeferredLog' => 'filesystem/PhutilDeferredLog.php',
    'PhutilDeferredLogTestCase' => 'filesystem/__tests__/PhutilDeferredLogTestCase.php',
    'PhutilDiffBinaryAnalyzer' => 'filesystem/binary/PhutilDiffBinaryAnalyzer.php',
    'PhutilDirectedScalarGraph' => 'utils/PhutilDirectedScalarGraph.php',
    'PhutilDirectoryFixture' => 'filesystem/PhutilDirectoryFixture.php',
    'PhutilDocblockParser' => 'parser/PhutilDocblockParser.php',
    'PhutilDocblockParserTestCase' => 'parser/__tests__/PhutilDocblockParserTestCase.php',
    'PhutilEditDistanceMatrix' => 'utils/PhutilEditDistanceMatrix.php',
    'PhutilEditDistanceMatrixTestCase' => 'utils/__tests__/PhutilEditDistanceMatrixTestCase.php',
    'PhutilEditorConfig' => 'parser/PhutilEditorConfig.php',
    'PhutilEditorConfigTestCase' => 'parser/__tests__/PhutilEditorConfigTestCase.php',
    'PhutilEmailAddress' => 'parser/PhutilEmailAddress.php',
    'PhutilEmailAddressTestCase' => 'parser/__tests__/PhutilEmailAddressTestCase.php',
    'PhutilEmojiLocale' => 'internationalization/locales/PhutilEmojiLocale.php',
    'PhutilEnglishCanadaLocale' => 'internationalization/locales/PhutilEnglishCanadaLocale.php',
    'PhutilErrorHandler' => 'error/PhutilErrorHandler.php',
    'PhutilErrorHandlerTestCase' => 'error/__tests__/PhutilErrorHandlerTestCase.php',
    'PhutilErrorTrap' => 'error/PhutilErrorTrap.php',
    'PhutilEvent' => 'events/PhutilEvent.php',
    'PhutilEventConstants' => 'events/constant/PhutilEventConstants.php',
    'PhutilEventEngine' => 'events/PhutilEventEngine.php',
    'PhutilEventListener' => 'events/PhutilEventListener.php',
    'PhutilEventType' => 'events/constant/PhutilEventType.php',
    'PhutilExampleBufferedIterator' => 'utils/PhutilExampleBufferedIterator.php',
    'PhutilExecChannel' => 'channel/PhutilExecChannel.php',
    'PhutilExecPassthru' => 'future/exec/PhutilExecPassthru.php',
    'PhutilExecutableFuture' => 'future/exec/PhutilExecutableFuture.php',
    'PhutilExecutionEnvironment' => 'utils/PhutilExecutionEnvironment.php',
    'PhutilFileLock' => 'filesystem/PhutilFileLock.php',
    'PhutilFileLockTestCase' => 'filesystem/__tests__/PhutilFileLockTestCase.php',
    'PhutilFrenchLocale' => 'internationalization/locales/PhutilFrenchLocale.php',
    'PhutilGermanLocale' => 'internationalization/locales/PhutilGermanLocale.php',
    'PhutilGitBinaryAnalyzer' => 'filesystem/binary/PhutilGitBinaryAnalyzer.php',
    'PhutilGitHubFuture' => 'future/github/PhutilGitHubFuture.php',
    'PhutilGitHubResponse' => 'future/github/PhutilGitHubResponse.php',
    'PhutilGitURI' => 'parser/PhutilGitURI.php',
    'PhutilGitURITestCase' => 'parser/__tests__/PhutilGitURITestCase.php',
    'PhutilHTMLParser' => 'parser/html/PhutilHTMLParser.php',
    'PhutilHTMLParserTestCase' => 'parser/html/__tests__/PhutilHTMLParserTestCase.php',
    'PhutilHTTPEngineExtension' => 'future/http/PhutilHTTPEngineExtension.php',
    'PhutilHTTPResponse' => 'parser/http/PhutilHTTPResponse.php',
    'PhutilHTTPResponseParser' => 'parser/http/PhutilHTTPResponseParser.php',
    'PhutilHTTPResponseParserTestCase' => 'parser/http/__tests__/PhutilHTTPResponseParserTestCase.php',
    'PhutilHashingIterator' => 'utils/PhutilHashingIterator.php',
    'PhutilHashingIteratorTestCase' => 'utils/__tests__/PhutilHashingIteratorTestCase.php',
    'PhutilHelpArgumentWorkflow' => 'parser/argument/workflow/PhutilHelpArgumentWorkflow.php',
    'PhutilHgsprintfTestCase' => 'xsprintf/__tests__/PhutilHgsprintfTestCase.php',
    'PhutilINIParserException' => 'parser/exception/PhutilINIParserException.php',
    'PhutilIPAddress' => 'ip/PhutilIPAddress.php',
    'PhutilIPAddressTestCase' => 'ip/__tests__/PhutilIPAddressTestCase.php',
    'PhutilIPv4Address' => 'ip/PhutilIPv4Address.php',
    'PhutilIPv6Address' => 'ip/PhutilIPv6Address.php',
    'PhutilInteractiveEditor' => 'console/PhutilInteractiveEditor.php',
    'PhutilInvalidRuleParserGeneratorException' => 'parser/generator/exception/PhutilInvalidRuleParserGeneratorException.php',
    'PhutilInvalidStateException' => 'exception/PhutilInvalidStateException.php',
    'PhutilInvalidStateExceptionTestCase' => 'exception/__tests__/PhutilInvalidStateExceptionTestCase.php',
    'PhutilIrreducibleRuleParserGeneratorException' => 'parser/generator/exception/PhutilIrreducibleRuleParserGeneratorException.php',
    'PhutilJSON' => 'parser/PhutilJSON.php',
    'PhutilJSONFragmentLexer' => 'lexer/PhutilJSONFragmentLexer.php',
    'PhutilJSONParser' => 'parser/PhutilJSONParser.php',
    'PhutilJSONParserException' => 'parser/exception/PhutilJSONParserException.php',
    'PhutilJSONParserTestCase' => 'parser/__tests__/PhutilJSONParserTestCase.php',
    'PhutilJSONProtocolChannel' => 'channel/PhutilJSONProtocolChannel.php',
    'PhutilJSONProtocolChannelTestCase' => 'channel/__tests__/PhutilJSONProtocolChannelTestCase.php',
    'PhutilJSONTestCase' => 'parser/__tests__/PhutilJSONTestCase.php',
    'PhutilJavaFragmentLexer' => 'lexer/PhutilJavaFragmentLexer.php',
    'PhutilKoreanLocale' => 'internationalization/locales/PhutilKoreanLocale.php',
    'PhutilLanguageGuesser' => 'parser/PhutilLanguageGuesser.php',
    'PhutilLanguageGuesserTestCase' => 'parser/__tests__/PhutilLanguageGuesserTestCase.php',
    'PhutilLexer' => 'lexer/PhutilLexer.php',
    'PhutilLibraryConflictException' => 'init/lib/PhutilLibraryConflictException.php',
    'PhutilLibraryMapBuilder' => 'moduleutils/PhutilLibraryMapBuilder.php',
    'PhutilLibraryTestCase' => '__tests__/PhutilLibraryTestCase.php',
    'PhutilLocale' => 'internationalization/PhutilLocale.php',
    'PhutilLocaleTestCase' => 'internationalization/__tests__/PhutilLocaleTestCase.php',
    'PhutilLock' => 'filesystem/PhutilLock.php',
    'PhutilLockException' => 'filesystem/PhutilLockException.php',
    'PhutilLogFileChannel' => 'channel/PhutilLogFileChannel.php',
    'PhutilLunarPhase' => 'utils/PhutilLunarPhase.php',
    'PhutilLunarPhaseTestCase' => 'utils/__tests__/PhutilLunarPhaseTestCase.php',
    'PhutilMercurialBinaryAnalyzer' => 'filesystem/binary/PhutilMercurialBinaryAnalyzer.php',
    'PhutilMethodNotImplementedException' => 'error/PhutilMethodNotImplementedException.php',
    'PhutilMetricsChannel' => 'channel/PhutilMetricsChannel.php',
    'PhutilMissingSymbolException' => 'init/lib/PhutilMissingSymbolException.php',
    'PhutilModuleUtilsTestCase' => 'init/lib/__tests__/PhutilModuleUtilsTestCase.php',
    'PhutilNumber' => 'internationalization/PhutilNumber.php',
    'PhutilOAuth1Future' => 'future/oauth/PhutilOAuth1Future.php',
    'PhutilOAuth1FutureTestCase' => 'future/oauth/__tests__/PhutilOAuth1FutureTestCase.php',
    'PhutilOpaqueEnvelope' => 'error/PhutilOpaqueEnvelope.php',
    'PhutilOpaqueEnvelopeKey' => 'error/PhutilOpaqueEnvelopeKey.php',
    'PhutilOpaqueEnvelopeTestCase' => 'error/__tests__/PhutilOpaqueEnvelopeTestCase.php',
    'PhutilPHPFragmentLexer' => 'lexer/PhutilPHPFragmentLexer.php',
    'PhutilPHPFragmentLexerTestCase' => 'lexer/__tests__/PhutilPHPFragmentLexerTestCase.php',
    'PhutilPHPObjectProtocolChannel' => 'channel/PhutilPHPObjectProtocolChannel.php',
    'PhutilPHPObjectProtocolChannelTestCase' => 'channel/__tests__/PhutilPHPObjectProtocolChannelTestCase.php',
    'PhutilParserGenerator' => 'parser/PhutilParserGenerator.php',
    'PhutilParserGeneratorException' => 'parser/generator/exception/PhutilParserGeneratorException.php',
    'PhutilParserGeneratorTestCase' => 'parser/__tests__/PhutilParserGeneratorTestCase.php',
    'PhutilPayPalAPIFuture' => 'future/paypal/PhutilPayPalAPIFuture.php',
    'PhutilPerson' => 'internationalization/PhutilPerson.php',
    'PhutilPersonTest' => 'internationalization/__tests__/PhutilPersonTest.php',
    'PhutilPhtTestCase' => 'internationalization/__tests__/PhutilPhtTestCase.php',
    'PhutilPirateEnglishLocale' => 'internationalization/locales/PhutilPirateEnglishLocale.php',
    'PhutilPortugueseBrazilLocale' => 'internationalization/locales/PhutilPortugueseBrazilLocale.php',
    'PhutilPortuguesePortugalLocale' => 'internationalization/locales/PhutilPortuguesePortugalLocale.php',
    'PhutilPostmarkFuture' => 'future/postmark/PhutilPostmarkFuture.php',
    'PhutilPregsprintfTestCase' => 'xsprintf/__tests__/PhutilPregsprintfTestCase.php',
    'PhutilProcessQuery' => 'filesystem/PhutilProcessQuery.php',
    'PhutilProcessRef' => 'filesystem/PhutilProcessRef.php',
    'PhutilProcessRefTestCase' => 'filesystem/__tests__/PhutilProcessRefTestCase.php',
    'PhutilProgressSink' => 'progress/PhutilProgressSink.php',
    'PhutilProtocolChannel' => 'channel/PhutilProtocolChannel.php',
    'PhutilProxyException' => 'error/PhutilProxyException.php',
    'PhutilProxyIterator' => 'utils/PhutilProxyIterator.php',
    'PhutilPygmentizeBinaryAnalyzer' => 'filesystem/binary/PhutilPygmentizeBinaryAnalyzer.php',
    'PhutilPythonFragmentLexer' => 'lexer/PhutilPythonFragmentLexer.php',
    'PhutilQueryStringParser' => 'parser/PhutilQueryStringParser.php',
    'PhutilQueryStringParserTestCase' => 'parser/__tests__/PhutilQueryStringParserTestCase.php',
    'PhutilRawEnglishLocale' => 'internationalization/locales/PhutilRawEnglishLocale.php',
    'PhutilReadableSerializer' => 'readableserializer/PhutilReadableSerializer.php',
    'PhutilReadableSerializerTestCase' => 'readableserializer/__tests__/PhutilReadableSerializerTestCase.php',
    'PhutilRope' => 'utils/PhutilRope.php',
    'PhutilRopeTestCase' => 'utils/__tests__/PhutilRopeTestCase.php',
    'PhutilServiceProfiler' => 'serviceprofiler/PhutilServiceProfiler.php',
    'PhutilShellLexer' => 'lexer/PhutilShellLexer.php',
    'PhutilShellLexerTestCase' => 'lexer/__tests__/PhutilShellLexerTestCase.php',
    'PhutilSignalHandler' => 'future/exec/PhutilSignalHandler.php',
    'PhutilSignalRouter' => 'future/exec/PhutilSignalRouter.php',
    'PhutilSimpleOptions' => 'parser/PhutilSimpleOptions.php',
    'PhutilSimpleOptionsLexer' => 'lexer/PhutilSimpleOptionsLexer.php',
    'PhutilSimpleOptionsLexerTestCase' => 'lexer/__tests__/PhutilSimpleOptionsLexerTestCase.php',
    'PhutilSimpleOptionsTestCase' => 'parser/__tests__/PhutilSimpleOptionsTestCase.php',
    'PhutilSimplifiedChineseLocale' => 'internationalization/locales/PhutilSimplifiedChineseLocale.php',
    'PhutilSlackFuture' => 'future/slack/PhutilSlackFuture.php',
    'PhutilSocketChannel' => 'channel/PhutilSocketChannel.php',
    'PhutilSortVector' => 'utils/PhutilSortVector.php',
    'PhutilSpanishSpainLocale' => 'internationalization/locales/PhutilSpanishSpainLocale.php',
    'PhutilStreamIterator' => 'utils/PhutilStreamIterator.php',
    'PhutilSubversionBinaryAnalyzer' => 'filesystem/binary/PhutilSubversionBinaryAnalyzer.php',
    'PhutilSymbolLoader' => 'symbols/PhutilSymbolLoader.php',
    'PhutilSystem' => 'utils/PhutilSystem.php',
    'PhutilSystemTestCase' => 'utils/__tests__/PhutilSystemTestCase.php',
    'PhutilTerminalString' => 'xsprintf/PhutilTerminalString.php',
    'PhutilTestCase' => 'unit/engine/phutil/PhutilTestCase.php',
    'PhutilTestCaseTestCase' => 'unit/engine/phutil/testcase/PhutilTestCaseTestCase.php',
    'PhutilTestPhobject' => 'object/__tests__/PhutilTestPhobject.php',
    'PhutilTestSkippedException' => 'unit/engine/phutil/testcase/PhutilTestSkippedException.php',
    'PhutilTestTerminatedException' => 'unit/engine/phutil/testcase/PhutilTestTerminatedException.php',
    'PhutilTraditionalChineseLocale' => 'internationalization/locales/PhutilTraditionalChineseLocale.php',
    'PhutilTranslation' => 'internationalization/PhutilTranslation.php',
    'PhutilTranslationTestCase' => 'internationalization/__tests__/PhutilTranslationTestCase.php',
    'PhutilTranslator' => 'internationalization/PhutilTranslator.php',
    'PhutilTranslatorTestCase' => 'internationalization/__tests__/PhutilTranslatorTestCase.php',
    'PhutilTsprintfTestCase' => 'xsprintf/__tests__/PhutilTsprintfTestCase.php',
    'PhutilTwitchFuture' => 'future/twitch/PhutilTwitchFuture.php',
    'PhutilTypeCheckException' => 'parser/exception/PhutilTypeCheckException.php',
    'PhutilTypeExtraParametersException' => 'parser/exception/PhutilTypeExtraParametersException.php',
    'PhutilTypeLexer' => 'lexer/PhutilTypeLexer.php',
    'PhutilTypeMissingParametersException' => 'parser/exception/PhutilTypeMissingParametersException.php',
    'PhutilTypeSpec' => 'parser/PhutilTypeSpec.php',
    'PhutilTypeSpecTestCase' => 'parser/__tests__/PhutilTypeSpecTestCase.php',
    'PhutilURI' => 'parser/PhutilURI.php',
    'PhutilURITestCase' => 'parser/__tests__/PhutilURITestCase.php',
    'PhutilUSEnglishLocale' => 'internationalization/locales/PhutilUSEnglishLocale.php',
    'PhutilUTF8StringTruncator' => 'utils/PhutilUTF8StringTruncator.php',
    'PhutilUTF8TestCase' => 'utils/__tests__/PhutilUTF8TestCase.php',
    'PhutilUnitTestEngine' => 'unit/engine/PhutilUnitTestEngine.php',
    'PhutilUnitTestEngineTestCase' => 'unit/engine/__tests__/PhutilUnitTestEngineTestCase.php',
    'PhutilUnknownSymbolParserGeneratorException' => 'parser/generator/exception/PhutilUnknownSymbolParserGeneratorException.php',
    'PhutilUnreachableRuleParserGeneratorException' => 'parser/generator/exception/PhutilUnreachableRuleParserGeneratorException.php',
    'PhutilUnreachableTerminalParserGeneratorException' => 'parser/generator/exception/PhutilUnreachableTerminalParserGeneratorException.php',
    'PhutilUrisprintfTestCase' => 'xsprintf/__tests__/PhutilUrisprintfTestCase.php',
    'PhutilUtilsTestCase' => 'utils/__tests__/PhutilUtilsTestCase.php',
    'PhutilVeryWowEnglishLocale' => 'internationalization/locales/PhutilVeryWowEnglishLocale.php',
    'PhutilWordPressFuture' => 'future/wordpress/PhutilWordPressFuture.php',
    'PhutilXHPASTBinary' => 'parser/xhpast/bin/PhutilXHPASTBinary.php',
    'PytestTestEngine' => 'unit/engine/PytestTestEngine.php',
    'TempFile' => 'filesystem/TempFile.php',
    'TestAbstractDirectedGraph' => 'utils/__tests__/TestAbstractDirectedGraph.php',
    'XHPASTNode' => 'parser/xhpast/api/XHPASTNode.php',
    'XHPASTNodeTestCase' => 'parser/xhpast/api/__tests__/XHPASTNodeTestCase.php',
    'XHPASTSyntaxErrorException' => 'parser/xhpast/api/XHPASTSyntaxErrorException.php',
    'XHPASTToken' => 'parser/xhpast/api/XHPASTToken.php',
    'XHPASTTree' => 'parser/xhpast/api/XHPASTTree.php',
    'XHPASTTreeTestCase' => 'parser/xhpast/api/__tests__/XHPASTTreeTestCase.php',
    'XUnitTestEngine' => 'unit/engine/XUnitTestEngine.php',
    'XUnitTestResultParserTestCase' => 'unit/parser/__tests__/XUnitTestResultParserTestCase.php',
    'XsprintfUnknownConversionException' => 'xsprintf/exception/XsprintfUnknownConversionException.php',
  ),
  'function' => array(
    '__phutil_autoload' => 'init/init-library.php',
    'array_fuse' => 'utils/utils.php',
    'array_interleave' => 'utils/utils.php',
    'array_mergev' => 'utils/utils.php',
    'array_select_keys' => 'utils/utils.php',
    'assert_instances_of' => 'utils/utils.php',
    'assert_same_keys' => 'utils/utils.php',
    'assert_stringlike' => 'utils/utils.php',
    'coalesce' => 'utils/utils.php',
    'csprintf' => 'xsprintf/csprintf.php',
    'exec_manual' => 'future/exec/execx.php',
    'execx' => 'future/exec/execx.php',
    'head' => 'utils/utils.php',
    'head_key' => 'utils/utils.php',
    'hgsprintf' => 'xsprintf/hgsprintf.php',
    'id' => 'utils/utils.php',
    'idx' => 'utils/utils.php',
    'idxv' => 'utils/utils.php',
    'ifilter' => 'utils/utils.php',
    'igroup' => 'utils/utils.php',
    'ipull' => 'utils/utils.php',
    'isort' => 'utils/utils.php',
    'jsprintf' => 'xsprintf/jsprintf.php',
    'last' => 'utils/utils.php',
    'last_key' => 'utils/utils.php',
    'ldap_sprintf' => 'xsprintf/ldapsprintf.php',
    'mfilter' => 'utils/utils.php',
    'mgroup' => 'utils/utils.php',
    'mpull' => 'utils/utils.php',
    'msort' => 'utils/utils.php',
    'msortv' => 'utils/utils.php',
    'msortv_internal' => 'utils/utils.php',
    'msortv_natural' => 'utils/utils.php',
    'newv' => 'utils/utils.php',
    'nonempty' => 'utils/utils.php',
    'phlog' => 'error/phlog.php',
    'pht' => 'internationalization/pht.php',
    'phutil_build_http_querystring' => 'utils/utils.php',
    'phutil_build_http_querystring_from_pairs' => 'utils/utils.php',
    'phutil_censor_credentials' => 'utils/utils.php',
    'phutil_console_confirm' => 'console/format.php',
    'phutil_console_format' => 'console/format.php',
    'phutil_console_get_terminal_width' => 'console/format.php',
    'phutil_console_prompt' => 'console/format.php',
    'phutil_console_require_tty' => 'console/format.php',
    'phutil_console_select' => 'console/format.php',
    'phutil_console_wrap' => 'console/format.php',
    'phutil_count' => 'internationalization/pht.php',
    'phutil_date_format' => 'utils/viewutils.php',
    'phutil_decode_mime_header' => 'utils/utils.php',
    'phutil_deprecated' => 'init/lib/moduleutils.php',
    'phutil_describe_type' => 'utils/utils.php',
    'phutil_encode_log' => 'utils/utils.php',
    'phutil_error_listener_example' => 'error/phlog.php',
    'phutil_escape_uri' => 'utils/utils.php',
    'phutil_escape_uri_path_component' => 'utils/utils.php',
    'phutil_fnmatch' => 'utils/utils.php',
    'phutil_format_bytes' => 'utils/viewutils.php',
    'phutil_format_relative_time' => 'utils/viewutils.php',
    'phutil_format_relative_time_detailed' => 'utils/viewutils.php',
    'phutil_format_units_generic' => 'utils/viewutils.php',
    'phutil_fwrite_nonblocking_stream' => 'utils/utils.php',
    'phutil_get_current_library_name' => 'init/lib/moduleutils.php',
    'phutil_get_library_name_for_root' => 'init/lib/moduleutils.php',
    'phutil_get_library_root' => 'init/lib/moduleutils.php',
    'phutil_get_library_root_for_path' => 'init/lib/moduleutils.php',
    'phutil_get_signal_name' => 'future/exec/execx.php',
    'phutil_get_system_locale' => 'utils/utf8.php',
    'phutil_glue' => 'utils/utils.php',
    'phutil_hashes_are_identical' => 'utils/utils.php',
    'phutil_http_parameter_pair' => 'utils/utils.php',
    'phutil_ini_decode' => 'utils/utils.php',
    'phutil_is_hiphop_runtime' => 'utils/utils.php',
    'phutil_is_interactive' => 'utils/utils.php',
    'phutil_is_natural_list' => 'utils/utils.php',
    'phutil_is_noninteractive' => 'utils/utils.php',
    'phutil_is_system_locale_available' => 'utils/utf8.php',
    'phutil_is_utf8' => 'utils/utf8.php',
    'phutil_is_utf8_slowly' => 'utils/utf8.php',
    'phutil_is_utf8_with_only_bmp_characters' => 'utils/utf8.php',
    'phutil_is_windows' => 'utils/utils.php',
    'phutil_json_decode' => 'utils/utils.php',
    'phutil_json_encode' => 'utils/utils.php',
    'phutil_load_library' => 'init/lib/moduleutils.php',
    'phutil_loggable_string' => 'utils/utils.php',
    'phutil_microseconds_since' => 'utils/utils.php',
    'phutil_parse_bytes' => 'utils/viewutils.php',
    'phutil_partition' => 'utils/utils.php',
    'phutil_passthru' => 'future/exec/execx.php',
    'phutil_person' => 'internationalization/pht.php',
    'phutil_register_library' => 'init/lib/core.php',
    'phutil_register_library_map' => 'init/lib/core.php',
    'phutil_set_system_locale' => 'utils/utf8.php',
    'phutil_split_lines' => 'utils/utils.php',
    'phutil_string_cast' => 'utils/utils.php',
    'phutil_unescape_uri_path_component' => 'utils/utils.php',
    'phutil_units' => 'utils/utils.php',
    'phutil_utf8_console_strlen' => 'utils/utf8.php',
    'phutil_utf8_convert' => 'utils/utf8.php',
    'phutil_utf8_encode_codepoint' => 'utils/utf8.php',
    'phutil_utf8_hard_wrap' => 'utils/utf8.php',
    'phutil_utf8_hard_wrap_html' => 'utils/utf8.php',
    'phutil_utf8_is_cjk' => 'utils/utf8.php',
    'phutil_utf8_is_combining_character' => 'utils/utf8.php',
    'phutil_utf8_strlen' => 'utils/utf8.php',
    'phutil_utf8_strtolower' => 'utils/utf8.php',
    'phutil_utf8_strtoupper' => 'utils/utf8.php',
    'phutil_utf8_strtr' => 'utils/utf8.php',
    'phutil_utf8_ucwords' => 'utils/utf8.php',
    'phutil_utf8ize' => 'utils/utf8.php',
    'phutil_utf8v' => 'utils/utf8.php',
    'phutil_utf8v_codepoints' => 'utils/utf8.php',
    'phutil_utf8v_combine_characters' => 'utils/utf8.php',
    'phutil_utf8v_combined' => 'utils/utf8.php',
    'phutil_validate_json' => 'utils/utils.php',
    'phutil_var_export' => 'utils/utils.php',
    'ppull' => 'utils/utils.php',
    'pregsprintf' => 'xsprintf/pregsprintf.php',
    'tsprintf' => 'xsprintf/tsprintf.php',
    'urisprintf' => 'xsprintf/urisprintf.php',
    'vcsprintf' => 'xsprintf/csprintf.php',
    'vjsprintf' => 'xsprintf/jsprintf.php',
    'vurisprintf' => 'xsprintf/urisprintf.php',
    'xhp_parser_node_constants' => 'parser/xhpast/parser_nodes.php',
    'xhpast_parser_token_constants' => 'parser/xhpast/parser_tokens.php',
    'xsprintf' => 'xsprintf/xsprintf.php',
    'xsprintf_callback_example' => 'xsprintf/xsprintf.php',
    'xsprintf_command' => 'xsprintf/csprintf.php',
    'xsprintf_javascript' => 'xsprintf/jsprintf.php',
    'xsprintf_ldap' => 'xsprintf/ldapsprintf.php',
    'xsprintf_mercurial' => 'xsprintf/hgsprintf.php',
    'xsprintf_regex' => 'xsprintf/pregsprintf.php',
    'xsprintf_terminal' => 'xsprintf/tsprintf.php',
    'xsprintf_uri' => 'xsprintf/urisprintf.php',
  ),
  'xmap' => array(
    'AASTNode' => 'Phobject',
    'AASTNodeList' => array(
      'Phobject',
      'Countable',
      'Iterator',
    ),
    'AASTToken' => 'Phobject',
    'AASTTree' => 'Phobject',
    'AbstractDirectedGraph' => 'Phobject',
    'AbstractDirectedGraphTestCase' => 'PhutilTestCase',
    'ArcanistAbstractMethodBodyXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistAbstractMethodBodyXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistAbstractPrivateMethodXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistAbstractPrivateMethodXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistAlias' => 'Phobject',
    'ArcanistAliasEffect' => 'Phobject',
    'ArcanistAliasEngine' => 'Phobject',
    'ArcanistAliasFunctionXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistAliasFunctionXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistAliasWorkflow' => 'ArcanistWorkflow',
    'ArcanistAliasesConfigOption' => 'ArcanistMultiSourceConfigOption',
    'ArcanistAmendWorkflow' => 'ArcanistArcWorkflow',
    'ArcanistAnoidWorkflow' => 'ArcanistArcWorkflow',
    'ArcanistArcConfigurationEngineExtension' => 'ArcanistConfigurationEngineExtension',
    'ArcanistArcToolset' => 'ArcanistToolset',
    'ArcanistArcWorkflow' => 'ArcanistWorkflow',
    'ArcanistArrayCombineXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistArrayCombineXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistArrayIndexSpacingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistArrayIndexSpacingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistArraySeparatorXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistArraySeparatorXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistArrayValueXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistArrayValueXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistBaseCommitParser' => 'Phobject',
    'ArcanistBaseCommitParserTestCase' => 'PhutilTestCase',
    'ArcanistBaseXHPASTLinter' => 'ArcanistFutureLinter',
    'ArcanistBinaryExpressionSpacingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistBinaryExpressionSpacingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistBinaryNumericScalarCasingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistBinaryNumericScalarCasingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistBlacklistedFunctionXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistBlacklistedFunctionXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistBlindlyTrustHTTPEngineExtension' => 'PhutilHTTPEngineExtension',
    'ArcanistBookmarksWorkflow' => 'ArcanistMarkersWorkflow',
    'ArcanistBoolConfigOption' => 'ArcanistSingleSourceConfigOption',
    'ArcanistBraceFormattingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistBraceFormattingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistBranchesWorkflow' => 'ArcanistMarkersWorkflow',
    'ArcanistBrowseCommitHardpointQuery' => 'ArcanistRuntimeHardpointQuery',
    'ArcanistBrowseCommitURIHardpointQuery' => 'ArcanistBrowseURIHardpointQuery',
    'ArcanistBrowseObjectNameURIHardpointQuery' => 'ArcanistBrowseURIHardpointQuery',
    'ArcanistBrowsePathURIHardpointQuery' => 'ArcanistBrowseURIHardpointQuery',
    'ArcanistBrowseRef' => 'ArcanistRef',
    'ArcanistBrowseRefInspector' => 'ArcanistRefInspector',
    'ArcanistBrowseRevisionURIHardpointQuery' => 'ArcanistBrowseURIHardpointQuery',
    'ArcanistBrowseURIHardpointQuery' => 'ArcanistRuntimeHardpointQuery',
    'ArcanistBrowseURIRef' => 'ArcanistRef',
    'ArcanistBrowseWorkflow' => 'ArcanistArcWorkflow',
    'ArcanistBuildBuildplanHardpointQuery' => 'ArcanistRuntimeHardpointQuery',
    'ArcanistBuildPlanRef' => 'ArcanistRef',
    'ArcanistBuildPlanSymbolRef' => 'ArcanistSimpleSymbolRef',
    'ArcanistBuildRef' => 'ArcanistRef',
    'ArcanistBuildSymbolRef' => 'ArcanistSimpleSymbolRef',
    'ArcanistBuildableBuildsHardpointQuery' => 'ArcanistRuntimeHardpointQuery',
    'ArcanistBuildableRef' => 'ArcanistRef',
    'ArcanistBuildableSymbolRef' => 'ArcanistSimpleSymbolRef',
    'ArcanistBundle' => 'Phobject',
    'ArcanistBundleTestCase' => 'PhutilTestCase',
    'ArcanistCSSLintLinter' => 'ArcanistExternalLinter',
    'ArcanistCSSLintLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistCSharpLinter' => 'ArcanistLinter',
    'ArcanistCallConduitWorkflow' => 'ArcanistArcWorkflow',
    'ArcanistCallParenthesesXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistCallParenthesesXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistCallTimePassByReferenceXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistCallTimePassByReferenceXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistCapabilityNotSupportedException' => 'Exception',
    'ArcanistCastSpacingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistCastSpacingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistCheckstyleXMLLintRenderer' => 'ArcanistLintRenderer',
    'ArcanistChmodLinter' => 'ArcanistLinter',
    'ArcanistChmodLinterTestCase' => 'ArcanistLinterTestCase',
    'ArcanistClassExtendsObjectXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistClassExtendsObjectXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistClassFilenameMismatchXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistClassMustBeDeclaredAbstractXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistClassMustBeDeclaredAbstractXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistClassNameLiteralXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistClassNameLiteralXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistCloseRevisionWorkflow' => 'ArcanistWorkflow',
    'ArcanistClosureLinter' => 'ArcanistExternalLinter',
    'ArcanistClosureLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistCoffeeLintLinter' => 'ArcanistExternalLinter',
    'ArcanistCoffeeLintLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistCommand' => 'Phobject',
    'ArcanistCommentRemover' => 'Phobject',
    'ArcanistCommentRemoverTestCase' => 'PhutilTestCase',
    'ArcanistCommentSpacingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistCommentStyleXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistCommentStyleXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistCommitGraph' => 'Phobject',
    'ArcanistCommitGraphPartition' => 'Phobject',
    'ArcanistCommitGraphPartitionQuery' => 'Phobject',
    'ArcanistCommitGraphQuery' => 'Phobject',
    'ArcanistCommitGraphSet' => 'Phobject',
    'ArcanistCommitGraphSetQuery' => 'Phobject',
    'ArcanistCommitGraphSetTreeView' => 'Phobject',
    'ArcanistCommitGraphSetView' => 'Phobject',
    'ArcanistCommitGraphTestCase' => 'PhutilTestCase',
    'ArcanistCommitNode' => 'Phobject',
    'ArcanistCommitRef' => 'ArcanistRef',
    'ArcanistCommitSymbolRef' => 'ArcanistSymbolRef',
    'ArcanistCommitSymbolRefInspector' => 'ArcanistRefInspector',
    'ArcanistCommitUpstreamHardpointQuery' => 'ArcanistRuntimeHardpointQuery',
    'ArcanistCommitWorkflow' => 'ArcanistWorkflow',
    'ArcanistCompilerLintRenderer' => 'ArcanistLintRenderer',
    'ArcanistComposerLinter' => 'ArcanistLinter',
    'ArcanistComprehensiveLintEngine' => 'ArcanistLintEngine',
    'ArcanistConcatenationOperatorXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistConcatenationOperatorXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistConduitAuthenticationException' => 'Exception',
    'ArcanistConduitCallFuture' => 'FutureProxy',
    'ArcanistConduitEngine' => 'Phobject',
    'ArcanistConduitException' => 'Exception',
    'ArcanistConfigOption' => 'Phobject',
    'ArcanistConfiguration' => 'Phobject',
    'ArcanistConfigurationDrivenLintEngine' => 'ArcanistLintEngine',
    'ArcanistConfigurationDrivenUnitTestEngine' => 'ArcanistUnitTestEngine',
    'ArcanistConfigurationEngine' => 'Phobject',
    'ArcanistConfigurationEngineExtension' => 'Phobject',
    'ArcanistConfigurationManager' => 'Phobject',
    'ArcanistConfigurationSource' => 'Phobject',
    'ArcanistConfigurationSourceList' => 'Phobject',
    'ArcanistConfigurationSourceValue' => 'Phobject',
    'ArcanistConsoleLintRenderer' => 'ArcanistLintRenderer',
    'ArcanistConsoleLintRendererTestCase' => 'PhutilTestCase',
    'ArcanistConstructorParenthesesXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistConstructorParenthesesXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistContinueInsideSwitchXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistContinueInsideSwitchXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistControlStatementSpacingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistControlStatementSpacingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistCoverWorkflow' => 'ArcanistWorkflow',
    'ArcanistCppcheckLinter' => 'ArcanistExternalLinter',
    'ArcanistCppcheckLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistCpplintLinter' => 'ArcanistExternalLinter',
    'ArcanistCpplintLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistCurlyBraceArrayIndexXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistCurlyBraceArrayIndexXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistDeclarationParenthesesXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistDeclarationParenthesesXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistDefaultParametersXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistDefaultParametersXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistDefaultsConfigurationSource' => 'ArcanistDictionaryConfigurationSource',
    'ArcanistDeprecationXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistDeprecationXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistDictionaryConfigurationSource' => 'ArcanistConfigurationSource',
    'ArcanistDiffByteSizeException' => 'Exception',
    'ArcanistDiffChange' => 'Phobject',
    'ArcanistDiffChangeType' => 'Phobject',
    'ArcanistDiffHunk' => 'Phobject',
    'ArcanistDiffParser' => 'Phobject',
    'ArcanistDiffParserTestCase' => 'PhutilTestCase',
    'ArcanistDiffUtils' => 'Phobject',
    'ArcanistDiffUtilsTestCase' => 'PhutilTestCase',
    'ArcanistDiffVectorNode' => 'Phobject',
    'ArcanistDiffVectorTree' => 'Phobject',
    'ArcanistDiffWorkflow' => 'ArcanistWorkflow',
    'ArcanistDifferentialCommitMessage' => 'Phobject',
    'ArcanistDifferentialCommitMessageParserException' => 'Exception',
    'ArcanistDifferentialDependencyGraph' => 'AbstractDirectedGraph',
    'ArcanistDifferentialRevisionHash' => 'Phobject',
    'ArcanistDifferentialRevisionStatus' => 'Phobject',
    'ArcanistDoubleQuoteXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistDoubleQuoteXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistDownloadWorkflow' => 'ArcanistArcWorkflow',
    'ArcanistDuplicateKeysInArrayXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistDuplicateKeysInArrayXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistDuplicateSwitchCaseXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistDuplicateSwitchCaseXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistDynamicDefineXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistDynamicDefineXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistElseIfUsageXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistElseIfUsageXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistEmptyFileXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistEmptyStatementXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistEmptyStatementXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistEventType' => 'PhutilEventType',
    'ArcanistExitExpressionXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistExitExpressionXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistExportWorkflow' => 'ArcanistWorkflow',
    'ArcanistExternalLinter' => 'ArcanistFutureLinter',
    'ArcanistExternalLinterTestCase' => 'ArcanistLinterTestCase',
    'ArcanistExtractUseXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistExtractUseXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistFileConfigurationSource' => 'ArcanistFilesystemConfigurationSource',
    'ArcanistFileDataRef' => 'Phobject',
    'ArcanistFileRef' => 'ArcanistRef',
    'ArcanistFileSymbolRef' => 'ArcanistSimpleSymbolRef',
    'ArcanistFileUploader' => 'Phobject',
    'ArcanistFilenameLinter' => 'ArcanistLinter',
    'ArcanistFilenameLinterTestCase' => 'ArcanistLinterTestCase',
    'ArcanistFilesystemAPI' => 'ArcanistRepositoryAPI',
    'ArcanistFilesystemConfigurationSource' => 'ArcanistDictionaryConfigurationSource',
    'ArcanistFilesystemWorkingCopy' => 'ArcanistWorkingCopy',
    'ArcanistFlake8Linter' => 'ArcanistExternalLinter',
    'ArcanistFlake8LinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistFormattedStringXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistFormattedStringXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistFunctionCallShouldBeTypeCastXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistFunctionCallShouldBeTypeCastXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistFutureLinter' => 'ArcanistLinter',
    'ArcanistGeneratedLinter' => 'ArcanistLinter',
    'ArcanistGeneratedLinterTestCase' => 'ArcanistLinterTestCase',
    'ArcanistGetConfigWorkflow' => 'ArcanistWorkflow',
    'ArcanistGitAPI' => 'ArcanistRepositoryAPI',
    'ArcanistGitCommitGraphQuery' => 'ArcanistCommitGraphQuery',
    'ArcanistGitCommitMessageHardpointQuery' => 'ArcanistWorkflowGitHardpointQuery',
    'ArcanistGitCommitSymbolCommitHardpointQuery' => 'ArcanistWorkflowGitHardpointQuery',
    'ArcanistGitLandEngine' => 'ArcanistLandEngine',
    'ArcanistGitLocalState' => 'ArcanistRepositoryLocalState',
    'ArcanistGitRawCommit' => 'Phobject',
    'ArcanistGitRawCommitTestCase' => 'PhutilTestCase',
    'ArcanistGitRepositoryMarkerQuery' => 'ArcanistRepositoryMarkerQuery',
    'ArcanistGitRepositoryRemoteQuery' => 'ArcanistRepositoryRemoteQuery',
    'ArcanistGitUpstreamPath' => 'Phobject',
    'ArcanistGitWorkEngine' => 'ArcanistWorkEngine',
    'ArcanistGitWorkingCopy' => 'ArcanistWorkingCopy',
    'ArcanistGitWorkingCopyRevisionHardpointQuery' => 'ArcanistWorkflowGitHardpointQuery',
    'ArcanistGlobalVariableXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistGlobalVariableXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistGoLintLinter' => 'ArcanistExternalLinter',
    'ArcanistGoLintLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistGoTestResultParser' => 'ArcanistTestResultParser',
    'ArcanistGoTestResultParserTestCase' => 'PhutilTestCase',
    'ArcanistGridCell' => 'Phobject',
    'ArcanistGridColumn' => 'Phobject',
    'ArcanistGridRow' => 'Phobject',
    'ArcanistGridView' => 'Phobject',
    'ArcanistHLintLinter' => 'ArcanistExternalLinter',
    'ArcanistHLintLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistHardpoint' => 'Phobject',
    'ArcanistHardpointEngine' => 'Phobject',
    'ArcanistHardpointFutureList' => 'Phobject',
    'ArcanistHardpointList' => 'Phobject',
    'ArcanistHardpointObject' => 'Phobject',
    'ArcanistHardpointQuery' => 'Phobject',
    'ArcanistHardpointRequest' => 'Phobject',
    'ArcanistHardpointRequestList' => 'Phobject',
    'ArcanistHardpointTask' => 'Phobject',
    'ArcanistHardpointTaskResult' => 'Phobject',
    'ArcanistHelpWorkflow' => 'ArcanistWorkflow',
    'ArcanistHexadecimalNumericScalarCasingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistHexadecimalNumericScalarCasingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistHgClientChannel' => 'PhutilProtocolChannel',
    'ArcanistHgProxyClient' => 'Phobject',
    'ArcanistHgProxyServer' => 'Phobject',
    'ArcanistHgServerChannel' => 'PhutilProtocolChannel',
    'ArcanistImplicitConstructorXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistImplicitConstructorXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistImplicitFallthroughXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistImplicitFallthroughXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistImplicitVisibilityXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistImplicitVisibilityXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistImplodeArgumentOrderXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistImplodeArgumentOrderXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistInlineHTMLXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistInlineHTMLXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistInnerFunctionXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistInnerFunctionXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistInspectWorkflow' => 'ArcanistArcWorkflow',
    'ArcanistInstallCertificateWorkflow' => 'ArcanistWorkflow',
    'ArcanistInstanceOfOperatorXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistInstanceofOperatorXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistInterfaceAbstractMethodXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistInterfaceAbstractMethodXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistInterfaceMethodBodyXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistInterfaceMethodBodyXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistInvalidDefaultParameterXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistInvalidDefaultParameterXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistInvalidModifiersXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistInvalidModifiersXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistInvalidOctalNumericScalarXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistInvalidOctalNumericScalarXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistIsAShouldBeInstanceOfXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistIsAShouldBeInstanceOfXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistJSHintLinter' => 'ArcanistExternalLinter',
    'ArcanistJSHintLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistJSONLintLinter' => 'ArcanistExternalLinter',
    'ArcanistJSONLintRenderer' => 'ArcanistLintRenderer',
    'ArcanistJSONLinter' => 'ArcanistLinter',
    'ArcanistJSONLinterTestCase' => 'ArcanistLinterTestCase',
    'ArcanistJscsLinter' => 'ArcanistExternalLinter',
    'ArcanistJscsLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistKeywordCasingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistKeywordCasingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistLambdaFuncFunctionXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistLambdaFuncFunctionXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistLandCommit' => 'Phobject',
    'ArcanistLandCommitSet' => 'Phobject',
    'ArcanistLandEngine' => 'ArcanistWorkflowEngine',
    'ArcanistLandPushFailureException' => 'Exception',
    'ArcanistLandSymbol' => 'Phobject',
    'ArcanistLandTarget' => 'Phobject',
    'ArcanistLandWorkflow' => 'ArcanistArcWorkflow',
    'ArcanistLanguageConstructParenthesesXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistLanguageConstructParenthesesXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistLesscLinter' => 'ArcanistExternalLinter',
    'ArcanistLesscLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistLiberateWorkflow' => 'ArcanistArcWorkflow',
    'ArcanistLintEngine' => 'Phobject',
    'ArcanistLintMessage' => 'Phobject',
    'ArcanistLintMessageTestCase' => 'PhutilTestCase',
    'ArcanistLintPatcher' => 'Phobject',
    'ArcanistLintRenderer' => 'Phobject',
    'ArcanistLintResult' => 'Phobject',
    'ArcanistLintSeverity' => 'Phobject',
    'ArcanistLintWorkflow' => 'ArcanistWorkflow',
    'ArcanistLinter' => 'Phobject',
    'ArcanistLinterStandard' => 'Phobject',
    'ArcanistLinterStandardTestCase' => 'PhutilTestCase',
    'ArcanistLinterTestCase' => 'PhutilTestCase',
    'ArcanistLintersWorkflow' => 'ArcanistWorkflow',
    'ArcanistListAssignmentXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistListAssignmentXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistListConfigOption' => 'ArcanistSingleSourceConfigOption',
    'ArcanistListWorkflow' => 'ArcanistWorkflow',
    'ArcanistLocalConfigurationSource' => 'ArcanistWorkingCopyConfigurationSource',
    'ArcanistLogEngine' => 'Phobject',
    'ArcanistLogMessage' => 'Phobject',
    'ArcanistLogicalOperatorsXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistLogicalOperatorsXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistLookWorkflow' => 'ArcanistArcWorkflow',
    'ArcanistLowercaseFunctionsXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistLowercaseFunctionsXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistMarkerRef' => 'ArcanistRef',
    'ArcanistMarkersWorkflow' => 'ArcanistArcWorkflow',
    'ArcanistMercurialAPI' => 'ArcanistRepositoryAPI',
    'ArcanistMercurialCommitGraphQuery' => 'ArcanistCommitGraphQuery',
    'ArcanistMercurialCommitMessageHardpointQuery' => 'ArcanistWorkflowMercurialHardpointQuery',
    'ArcanistMercurialLandEngine' => 'ArcanistLandEngine',
    'ArcanistMercurialLocalState' => 'ArcanistRepositoryLocalState',
    'ArcanistMercurialParser' => 'Phobject',
    'ArcanistMercurialParserTestCase' => 'PhutilTestCase',
    'ArcanistMercurialRepositoryMarkerQuery' => 'ArcanistRepositoryMarkerQuery',
    'ArcanistMercurialRepositoryRemoteQuery' => 'ArcanistRepositoryRemoteQuery',
    'ArcanistMercurialWorkEngine' => 'ArcanistWorkEngine',
    'ArcanistMercurialWorkingCopy' => 'ArcanistWorkingCopy',
    'ArcanistMercurialWorkingCopyRevisionHardpointQuery' => 'ArcanistWorkflowMercurialHardpointQuery',
    'ArcanistMergeConflictLinter' => 'ArcanistLinter',
    'ArcanistMergeConflictLinterTestCase' => 'ArcanistLinterTestCase',
    'ArcanistMessageRevisionHardpointQuery' => 'ArcanistRuntimeHardpointQuery',
    'ArcanistMissingArgumentTerminatorException' => 'Exception',
    'ArcanistMissingLinterException' => 'Exception',
    'ArcanistModifierOrderingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistModifierOrderingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistMultiSourceConfigOption' => 'ArcanistConfigOption',
    'ArcanistNamespaceFirstStatementXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistNamespaceFirstStatementXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistNamingConventionsXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistNamingConventionsXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistNestedNamespacesXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistNestedNamespacesXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistNewlineAfterOpenTagXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistNewlineAfterOpenTagXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistNoEffectException' => 'ArcanistUsageException',
    'ArcanistNoEngineException' => 'ArcanistUsageException',
    'ArcanistNoLintLinter' => 'ArcanistLinter',
    'ArcanistNoLintLinterTestCase' => 'ArcanistLinterTestCase',
    'ArcanistNoParentScopeXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistNoParentScopeXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistNoURIConduitException' => 'ArcanistConduitException',
    'ArcanistNoneLintRenderer' => 'ArcanistLintRenderer',
    'ArcanistObjectListHardpoint' => 'ArcanistHardpoint',
    'ArcanistObjectOperatorSpacingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistObjectOperatorSpacingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistPEP8Linter' => 'ArcanistExternalLinter',
    'ArcanistPEP8LinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistPHPCloseTagXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistPHPCloseTagXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistPHPCompatibilityXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistPHPCompatibilityXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistPHPEchoTagXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistPHPEchoTagXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistPHPOpenTagXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistPHPOpenTagXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistPHPShortTagXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistPHPShortTagXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistPaamayimNekudotayimSpacingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistPaamayimNekudotayimSpacingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistParentMemberReferenceXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistParentMemberReferenceXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistParenthesesSpacingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistParenthesesSpacingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistParseStrUseXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistParseStrUseXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistPasteRef' => 'ArcanistRef',
    'ArcanistPasteSymbolRef' => 'ArcanistSimpleSymbolRef',
    'ArcanistPasteWorkflow' => 'ArcanistArcWorkflow',
    'ArcanistPatchWorkflow' => 'ArcanistWorkflow',
    'ArcanistPhpLinter' => 'ArcanistExternalLinter',
    'ArcanistPhpLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistPhpcsLinter' => 'ArcanistExternalLinter',
    'ArcanistPhpcsLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistPhpunitTestResultParser' => 'ArcanistTestResultParser',
    'ArcanistPhutilLibraryLinter' => 'ArcanistLinter',
    'ArcanistPhutilWorkflow' => 'PhutilArgumentWorkflow',
    'ArcanistPhutilXHPASTLinterStandard' => 'ArcanistLinterStandard',
    'ArcanistPlusOperatorOnStringsXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistPlusOperatorOnStringsXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistProjectConfigurationSource' => 'ArcanistWorkingCopyConfigurationSource',
    'ArcanistPrompt' => 'Phobject',
    'ArcanistPromptResponse' => 'Phobject',
    'ArcanistPromptsConfigOption' => 'ArcanistMultiSourceConfigOption',
    'ArcanistPromptsWorkflow' => 'ArcanistWorkflow',
    'ArcanistPublicPropertyXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistPublicPropertyXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistPuppetLintLinter' => 'ArcanistExternalLinter',
    'ArcanistPuppetLintLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistPyFlakesLinter' => 'ArcanistExternalLinter',
    'ArcanistPyFlakesLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistPyLintLinter' => 'ArcanistExternalLinter',
    'ArcanistPyLintLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistRaggedClassTreeEdgeXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistRaggedClassTreeEdgeXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistRef' => 'ArcanistHardpointObject',
    'ArcanistRefInspector' => 'Phobject',
    'ArcanistRefView' => array(
      'Phobject',
      'ArcanistTerminalStringInterface',
    ),
    'ArcanistRemoteRef' => 'ArcanistRef',
    'ArcanistRemoteRefInspector' => 'ArcanistRefInspector',
    'ArcanistRemoteRepositoryRefsHardpointQuery' => 'ArcanistRuntimeHardpointQuery',
    'ArcanistRepositoryAPI' => 'Phobject',
    'ArcanistRepositoryAPIMiscTestCase' => 'PhutilTestCase',
    'ArcanistRepositoryAPIStateTestCase' => 'PhutilTestCase',
    'ArcanistRepositoryLocalState' => 'Phobject',
    'ArcanistRepositoryMarkerQuery' => 'ArcanistRepositoryQuery',
    'ArcanistRepositoryQuery' => 'Phobject',
    'ArcanistRepositoryRef' => 'ArcanistRef',
    'ArcanistRepositoryRemoteQuery' => 'ArcanistRepositoryQuery',
    'ArcanistRepositoryURINormalizer' => 'Phobject',
    'ArcanistRepositoryURINormalizerTestCase' => 'PhutilTestCase',
    'ArcanistReusedAsIteratorXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistReusedAsIteratorXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistReusedIteratorReferenceXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistReusedIteratorReferenceXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistReusedIteratorXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistReusedIteratorXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistRevisionAuthorHardpointQuery' => 'ArcanistRuntimeHardpointQuery',
    'ArcanistRevisionBuildableHardpointQuery' => 'ArcanistRuntimeHardpointQuery',
    'ArcanistRevisionCommitMessageHardpointQuery' => 'ArcanistRuntimeHardpointQuery',
    'ArcanistRevisionParentRevisionsHardpointQuery' => 'ArcanistRuntimeHardpointQuery',
    'ArcanistRevisionRef' => 'ArcanistRef',
    'ArcanistRevisionRefSource' => 'Phobject',
    'ArcanistRevisionSymbolRef' => 'ArcanistSimpleSymbolRef',
    'ArcanistRuboCopLinter' => 'ArcanistExternalLinter',
    'ArcanistRuboCopLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistRubyLinter' => 'ArcanistExternalLinter',
    'ArcanistRubyLinterTestCase' => 'ArcanistExternalLinterTestCase',
    'ArcanistRuntimeConfigurationSource' => 'ArcanistDictionaryConfigurationSource',
    'ArcanistRuntimeHardpointQuery' => 'ArcanistHardpointQuery',
    'ArcanistScalarHardpoint' => 'ArcanistHardpoint',
    'ArcanistScriptAndRegexLinter' => 'ArcanistLinter',
    'ArcanistSelfClassReferenceXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistSelfClassReferenceXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistSelfMemberReferenceXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistSelfMemberReferenceXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistSemicolonSpacingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistSemicolonSpacingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistSetConfigWorkflow' => 'ArcanistWorkflow',
    'ArcanistSetting' => 'Phobject',
    'ArcanistSettings' => 'Phobject',
    'ArcanistShellCompleteWorkflow' => 'ArcanistWorkflow',
    'ArcanistSimpleCommitGraphQuery' => 'ArcanistCommitGraphQuery',
    'ArcanistSimpleSymbolHardpointQuery' => 'ArcanistRuntimeHardpointQuery',
    'ArcanistSimpleSymbolRef' => 'ArcanistSymbolRef',
    'ArcanistSimpleSymbolRefInspector' => 'ArcanistRefInspector',
    'ArcanistSingleLintEngine' => 'ArcanistLintEngine',
    'ArcanistSingleSourceConfigOption' => 'ArcanistConfigOption',
    'ArcanistSlownessXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistSlownessXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistSpellingLinter' => 'ArcanistLinter',
    'ArcanistSpellingLinterTestCase' => 'ArcanistLinterTestCase',
    'ArcanistStaticThisXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistStaticThisXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistStringConfigOption' => 'ArcanistSingleSourceConfigOption',
    'ArcanistStringListConfigOption' => 'ArcanistListConfigOption',
    'ArcanistSubversionAPI' => 'ArcanistRepositoryAPI',
    'ArcanistSubversionWorkingCopy' => 'ArcanistWorkingCopy',
    'ArcanistSummaryLintRenderer' => 'ArcanistLintRenderer',
    'ArcanistSymbolEngine' => 'Phobject',
    'ArcanistSymbolRef' => 'ArcanistRef',
    'ArcanistSyntaxErrorXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistSystemConfigurationSource' => 'ArcanistFilesystemConfigurationSource',
    'ArcanistTaskRef' => 'ArcanistRef',
    'ArcanistTaskSymbolRef' => 'ArcanistSimpleSymbolRef',
    'ArcanistTasksWorkflow' => 'ArcanistWorkflow',
    'ArcanistTautologicalExpressionXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistTautologicalExpressionXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistTestResultParser' => 'Phobject',
    'ArcanistTestXHPASTLintSwitchHook' => 'ArcanistXHPASTLintSwitchHook',
    'ArcanistTextLinter' => 'ArcanistLinter',
    'ArcanistTextLinterTestCase' => 'ArcanistLinterTestCase',
    'ArcanistThisReassignmentXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistThisReassignmentXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistToStringExceptionXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistToStringExceptionXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistTodoCommentXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistTodoCommentXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistTodoWorkflow' => 'ArcanistWorkflow',
    'ArcanistToolset' => 'Phobject',
    'ArcanistUSEnglishTranslation' => 'PhutilTranslation',
    'ArcanistUnableToParseXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistUnaryPostfixExpressionSpacingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistUnaryPostfixExpressionSpacingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistUnaryPrefixExpressionSpacingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistUnaryPrefixExpressionSpacingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistUndeclaredVariableXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistUndeclaredVariableXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistUnexpectedReturnValueXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistUnexpectedReturnValueXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistUnitConsoleRenderer' => 'ArcanistUnitRenderer',
    'ArcanistUnitRenderer' => 'Phobject',
    'ArcanistUnitTestEngine' => 'Phobject',
    'ArcanistUnitTestResult' => 'Phobject',
    'ArcanistUnitTestResultTestCase' => 'PhutilTestCase',
    'ArcanistUnitTestableLintEngine' => 'ArcanistLintEngine',
    'ArcanistUnitWorkflow' => 'ArcanistWorkflow',
    'ArcanistUnnecessaryFinalModifierXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistUnnecessaryFinalModifierXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistUnnecessarySemicolonXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistUnnecessarySymbolAliasXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistUnnecessarySymbolAliasXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistUnsafeDynamicStringXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistUnsafeDynamicStringXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistUpgradeWorkflow' => 'ArcanistArcWorkflow',
    'ArcanistUploadWorkflow' => 'ArcanistArcWorkflow',
    'ArcanistUsageException' => 'Exception',
    'ArcanistUseStatementNamespacePrefixXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistUseStatementNamespacePrefixXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistUselessOverridingMethodXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistUselessOverridingMethodXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistUserAbortException' => 'ArcanistUsageException',
    'ArcanistUserConfigurationSource' => 'ArcanistFilesystemConfigurationSource',
    'ArcanistUserRef' => 'ArcanistRef',
    'ArcanistUserSymbolHardpointQuery' => 'ArcanistRuntimeHardpointQuery',
    'ArcanistUserSymbolRef' => 'ArcanistSymbolRef',
    'ArcanistUserSymbolRefInspector' => 'ArcanistRefInspector',
    'ArcanistVariableReferenceSpacingXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistVariableReferenceSpacingXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistVariableVariableXHPASTLinterRule' => 'ArcanistXHPASTLinterRule',
    'ArcanistVariableVariableXHPASTLinterRuleTestCase' => 'ArcanistXHPASTLinterRuleTestCase',
    'ArcanistVectorHardpoint' => 'ArcanistHardpoint',
    'ArcanistVersionWorkflow' => 'ArcanistWorkflow',
    'ArcanistWeldWorkflow' => 'ArcanistArcWorkflow',
    'ArcanistWhichWorkflow' => 'ArcanistWorkflow',
    'ArcanistWildConfigOption' => 'ArcanistConfigOption',
    'ArcanistWorkEngine' => 'ArcanistWorkflowEngine',
    'ArcanistWorkWorkflow' => 'ArcanistArcWorkflow',
    'ArcanistWorkflow' => 'Phobject',
    'ArcanistWorkflowArgument' => 'Phobject',
    'ArcanistWorkflowEngine' => 'Phobject',
    'ArcanistWorkflowGitHardpointQuery' => 'ArcanistRuntimeHardpointQuery',
    'ArcanistWorkflowInformation' => 'Phobject',
    'ArcanistWorkflowMercurialHardpointQuery' => 'ArcanistRuntimeHardpointQuery',
    'ArcanistWorkingCopy' => 'Phobject',
    'ArcanistWorkingCopyConfigurationSource' => 'ArcanistFilesystemConfigurationSource',
    'ArcanistWorkingCopyIdentity' => 'Phobject',
    'ArcanistWorkingCopyPath' => 'Phobject',
    'ArcanistWorkingCopyStateRef' => 'ArcanistRef',
    'ArcanistWorkingCopyStateRefInspector' => 'ArcanistRefInspector',
    'ArcanistXHPASTLintNamingHook' => 'Phobject',
    'ArcanistXHPASTLintNamingHookTestCase' => 'PhutilTestCase',
    'ArcanistXHPASTLintSwitchHook' => 'Phobject',
    'ArcanistXHPASTLinter' => 'ArcanistBaseXHPASTLinter',
    'ArcanistXHPASTLinterRule' => 'Phobject',
    'ArcanistXHPASTLinterRuleTestCase' => 'ArcanistLinterTestCase',
    'ArcanistXHPASTLinterTestCase' => 'ArcanistLinterTestCase',
    'ArcanistXMLLinter' => 'ArcanistLinter',
    'ArcanistXMLLinterTestCase' => 'ArcanistLinterTestCase',
    'ArcanistXUnitTestResultParser' => 'Phobject',
    'BaseHTTPFuture' => 'Future',
    'CSharpToolsTestEngine' => 'XUnitTestEngine',
    'CaseInsensitiveArray' => 'PhutilArray',
    'CaseInsensitiveArrayTestCase' => 'PhutilTestCase',
    'CommandException' => 'Exception',
    'ConduitClient' => 'Phobject',
    'ConduitClientException' => 'Exception',
    'ConduitClientTestCase' => 'PhutilTestCase',
    'ConduitFuture' => 'FutureProxy',
    'ConduitSearchFuture' => 'FutureAgent',
    'ExecFuture' => 'PhutilExecutableFuture',
    'ExecFutureTestCase' => 'PhutilTestCase',
    'ExecPassthruTestCase' => 'PhutilTestCase',
    'FileFinder' => 'Phobject',
    'FileFinderTestCase' => 'PhutilTestCase',
    'FileList' => 'Phobject',
    'Filesystem' => 'Phobject',
    'FilesystemException' => 'Exception',
    'FilesystemTestCase' => 'PhutilTestCase',
    'Future' => 'Phobject',
    'FutureAgent' => 'Future',
    'FutureIterator' => array(
      'Phobject',
      'Iterator',
    ),
    'FutureIteratorTestCase' => 'PhutilTestCase',
    'FuturePool' => 'Phobject',
    'FutureProxy' => 'Future',
    'HTTPFuture' => 'BaseHTTPFuture',
    'HTTPFutureCURLResponseStatus' => 'HTTPFutureResponseStatus',
    'HTTPFutureCertificateResponseStatus' => 'HTTPFutureResponseStatus',
    'HTTPFutureHTTPResponseStatus' => 'HTTPFutureResponseStatus',
    'HTTPFutureParseResponseStatus' => 'HTTPFutureResponseStatus',
    'HTTPFutureResponseStatus' => 'Exception',
    'HTTPFutureTransportResponseStatus' => 'HTTPFutureResponseStatus',
    'HTTPSFuture' => 'BaseHTTPFuture',
    'ImmediateFuture' => 'Future',
    'LibphutilUSEnglishTranslation' => 'PhutilTranslation',
    'LinesOfALarge' => array(
      'Phobject',
      'Iterator',
    ),
    'LinesOfALargeExecFuture' => 'LinesOfALarge',
    'LinesOfALargeExecFutureTestCase' => 'PhutilTestCase',
    'LinesOfALargeFile' => 'LinesOfALarge',
    'LinesOfALargeFileTestCase' => 'PhutilTestCase',
    'MFilterTestHelper' => 'Phobject',
    'NoseTestEngine' => 'ArcanistUnitTestEngine',
    'PHPASTParserTestCase' => 'PhutilTestCase',
    'PhageAction' => 'Phobject',
    'PhageAgentAction' => 'PhageAction',
    'PhageAgentBootloader' => 'Phobject',
    'PhageAgentTestCase' => 'PhutilTestCase',
    'PhageExecWorkflow' => 'PhageWorkflow',
    'PhageExecuteAction' => 'PhageAction',
    'PhageLocalAction' => 'PhageAgentAction',
    'PhagePHPAgent' => 'Phobject',
    'PhagePHPAgentBootloader' => 'PhageAgentBootloader',
    'PhagePlanAction' => 'PhageAction',
    'PhageToolset' => 'ArcanistToolset',
    'PhageWorkflow' => 'ArcanistWorkflow',
    'Phobject' => 'Iterator',
    'PhobjectTestCase' => 'PhutilTestCase',
    'PhpunitTestEngine' => 'ArcanistUnitTestEngine',
    'PhpunitTestEngineTestCase' => 'PhutilTestCase',
    'PhutilAWSCloudFormationFuture' => 'PhutilAWSFuture',
    'PhutilAWSCloudWatchFuture' => 'PhutilAWSFuture',
    'PhutilAWSEC2Future' => 'PhutilAWSFuture',
    'PhutilAWSException' => 'Exception',
    'PhutilAWSFuture' => 'FutureProxy',
    'PhutilAWSManagementWorkflow' => 'PhutilArgumentWorkflow',
    'PhutilAWSS3DeleteManagementWorkflow' => 'PhutilAWSS3ManagementWorkflow',
    'PhutilAWSS3Future' => 'PhutilAWSFuture',
    'PhutilAWSS3GetManagementWorkflow' => 'PhutilAWSS3ManagementWorkflow',
    'PhutilAWSS3ManagementWorkflow' => 'PhutilAWSManagementWorkflow',
    'PhutilAWSS3PutManagementWorkflow' => 'PhutilAWSS3ManagementWorkflow',
    'PhutilAWSv4Signature' => 'Phobject',
    'PhutilAWSv4SignatureTestCase' => 'PhutilTestCase',
    'PhutilAggregateException' => 'Exception',
    'PhutilAllCapsEnglishLocale' => 'PhutilLocale',
    'PhutilArgumentParser' => 'Phobject',
    'PhutilArgumentParserException' => 'Exception',
    'PhutilArgumentParserTestCase' => 'PhutilTestCase',
    'PhutilArgumentSpecification' => 'Phobject',
    'PhutilArgumentSpecificationException' => 'PhutilArgumentParserException',
    'PhutilArgumentSpecificationTestCase' => 'PhutilTestCase',
    'PhutilArgumentSpellingCorrector' => 'Phobject',
    'PhutilArgumentSpellingCorrectorTestCase' => 'PhutilTestCase',
    'PhutilArgumentUsageException' => 'PhutilArgumentParserException',
    'PhutilArgumentWorkflow' => 'Phobject',
    'PhutilArray' => array(
      'Phobject',
      'Countable',
      'ArrayAccess',
      'Iterator',
    ),
    'PhutilArrayCheck' => 'Phobject',
    'PhutilArrayTestCase' => 'PhutilTestCase',
    'PhutilArrayWithDefaultValue' => 'PhutilArray',
    'PhutilAsanaFuture' => 'FutureProxy',
    'PhutilBacktraceSignalHandler' => 'PhutilSignalHandler',
    'PhutilBallOfPHP' => 'Phobject',
    'PhutilBinaryAnalyzer' => 'Phobject',
    'PhutilBinaryAnalyzerTestCase' => 'PhutilTestCase',
    'PhutilBootloaderException' => 'Exception',
    'PhutilBritishEnglishLocale' => 'PhutilLocale',
    'PhutilBufferedIterator' => array(
      'Phobject',
      'Iterator',
    ),
    'PhutilBufferedIteratorTestCase' => 'PhutilTestCase',
    'PhutilBugtraqParser' => 'Phobject',
    'PhutilBugtraqParserTestCase' => 'PhutilTestCase',
    'PhutilCIDRBlock' => 'Phobject',
    'PhutilCIDRList' => 'Phobject',
    'PhutilCallbackFilterIterator' => 'FilterIterator',
    'PhutilCallbackSignalHandler' => 'PhutilSignalHandler',
    'PhutilChannel' => 'Phobject',
    'PhutilChannelChannel' => 'PhutilChannel',
    'PhutilChannelTestCase' => 'PhutilTestCase',
    'PhutilChunkedIterator' => array(
      'Phobject',
      'Iterator',
    ),
    'PhutilChunkedIteratorTestCase' => 'PhutilTestCase',
    'PhutilClassMapQuery' => 'Phobject',
    'PhutilCloudWatchMetric' => 'Phobject',
    'PhutilCommandString' => 'Phobject',
    'PhutilConsole' => 'Phobject',
    'PhutilConsoleBlock' => 'PhutilConsoleView',
    'PhutilConsoleError' => 'PhutilConsoleLogLine',
    'PhutilConsoleFormatter' => 'Phobject',
    'PhutilConsoleInfo' => 'PhutilConsoleLogLine',
    'PhutilConsoleList' => 'PhutilConsoleView',
    'PhutilConsoleLogLine' => 'PhutilConsoleView',
    'PhutilConsoleMessage' => 'Phobject',
    'PhutilConsoleMetrics' => 'Phobject',
    'PhutilConsoleMetricsSignalHandler' => 'PhutilSignalHandler',
    'PhutilConsoleProgressBar' => 'Phobject',
    'PhutilConsoleProgressSink' => 'PhutilProgressSink',
    'PhutilConsoleServer' => 'Phobject',
    'PhutilConsoleServerChannel' => 'PhutilChannelChannel',
    'PhutilConsoleSkip' => 'PhutilConsoleLogLine',
    'PhutilConsoleStdinNotInteractiveException' => 'Exception',
    'PhutilConsoleTable' => 'PhutilConsoleView',
    'PhutilConsoleView' => 'Phobject',
    'PhutilConsoleWarning' => 'PhutilConsoleLogLine',
    'PhutilConsoleWrapTestCase' => 'PhutilTestCase',
    'PhutilCowsay' => 'Phobject',
    'PhutilCowsayTestCase' => 'PhutilTestCase',
    'PhutilCsprintfTestCase' => 'PhutilTestCase',
    'PhutilCzechLocale' => 'PhutilLocale',
    'PhutilDOMNode' => 'Phobject',
    'PhutilDeferredLog' => 'Phobject',
    'PhutilDeferredLogTestCase' => 'PhutilTestCase',
    'PhutilDiffBinaryAnalyzer' => 'PhutilBinaryAnalyzer',
    'PhutilDirectedScalarGraph' => 'AbstractDirectedGraph',
    'PhutilDirectoryFixture' => 'Phobject',
    'PhutilDocblockParser' => 'Phobject',
    'PhutilDocblockParserTestCase' => 'PhutilTestCase',
    'PhutilEditDistanceMatrix' => 'Phobject',
    'PhutilEditDistanceMatrixTestCase' => 'PhutilTestCase',
    'PhutilEditorConfig' => 'Phobject',
    'PhutilEditorConfigTestCase' => 'PhutilTestCase',
    'PhutilEmailAddress' => 'Phobject',
    'PhutilEmailAddressTestCase' => 'PhutilTestCase',
    'PhutilEmojiLocale' => 'PhutilLocale',
    'PhutilEnglishCanadaLocale' => 'PhutilLocale',
    'PhutilErrorHandler' => 'Phobject',
    'PhutilErrorHandlerTestCase' => 'PhutilTestCase',
    'PhutilErrorTrap' => 'Phobject',
    'PhutilEvent' => 'Phobject',
    'PhutilEventConstants' => 'Phobject',
    'PhutilEventEngine' => 'Phobject',
    'PhutilEventListener' => 'Phobject',
    'PhutilEventType' => 'PhutilEventConstants',
    'PhutilExampleBufferedIterator' => 'PhutilBufferedIterator',
    'PhutilExecChannel' => 'PhutilChannel',
    'PhutilExecPassthru' => 'PhutilExecutableFuture',
    'PhutilExecutableFuture' => 'Future',
    'PhutilExecutionEnvironment' => 'Phobject',
    'PhutilFileLock' => 'PhutilLock',
    'PhutilFileLockTestCase' => 'PhutilTestCase',
    'PhutilFrenchLocale' => 'PhutilLocale',
    'PhutilGermanLocale' => 'PhutilLocale',
    'PhutilGitBinaryAnalyzer' => 'PhutilBinaryAnalyzer',
    'PhutilGitHubFuture' => 'FutureProxy',
    'PhutilGitHubResponse' => 'Phobject',
    'PhutilGitURI' => 'Phobject',
    'PhutilGitURITestCase' => 'PhutilTestCase',
    'PhutilHTMLParser' => 'Phobject',
    'PhutilHTMLParserTestCase' => 'PhutilTestCase',
    'PhutilHTTPEngineExtension' => 'Phobject',
    'PhutilHTTPResponse' => 'Phobject',
    'PhutilHTTPResponseParser' => 'Phobject',
    'PhutilHTTPResponseParserTestCase' => 'PhutilTestCase',
    'PhutilHashingIterator' => array(
      'PhutilProxyIterator',
      'Iterator',
    ),
    'PhutilHashingIteratorTestCase' => 'PhutilTestCase',
    'PhutilHelpArgumentWorkflow' => 'PhutilArgumentWorkflow',
    'PhutilHgsprintfTestCase' => 'PhutilTestCase',
    'PhutilINIParserException' => 'Exception',
    'PhutilIPAddress' => 'Phobject',
    'PhutilIPAddressTestCase' => 'PhutilTestCase',
    'PhutilIPv4Address' => 'PhutilIPAddress',
    'PhutilIPv6Address' => 'PhutilIPAddress',
    'PhutilInteractiveEditor' => 'Phobject',
    'PhutilInvalidRuleParserGeneratorException' => 'PhutilParserGeneratorException',
    'PhutilInvalidStateException' => 'Exception',
    'PhutilInvalidStateExceptionTestCase' => 'PhutilTestCase',
    'PhutilIrreducibleRuleParserGeneratorException' => 'PhutilParserGeneratorException',
    'PhutilJSON' => 'Phobject',
    'PhutilJSONFragmentLexer' => 'PhutilLexer',
    'PhutilJSONParser' => 'Phobject',
    'PhutilJSONParserException' => 'Exception',
    'PhutilJSONParserTestCase' => 'PhutilTestCase',
    'PhutilJSONProtocolChannel' => 'PhutilProtocolChannel',
    'PhutilJSONProtocolChannelTestCase' => 'PhutilTestCase',
    'PhutilJSONTestCase' => 'PhutilTestCase',
    'PhutilJavaFragmentLexer' => 'PhutilLexer',
    'PhutilKoreanLocale' => 'PhutilLocale',
    'PhutilLanguageGuesser' => 'Phobject',
    'PhutilLanguageGuesserTestCase' => 'PhutilTestCase',
    'PhutilLexer' => 'Phobject',
    'PhutilLibraryConflictException' => 'Exception',
    'PhutilLibraryMapBuilder' => 'Phobject',
    'PhutilLibraryTestCase' => 'PhutilTestCase',
    'PhutilLocale' => 'Phobject',
    'PhutilLocaleTestCase' => 'PhutilTestCase',
    'PhutilLock' => 'Phobject',
    'PhutilLockException' => 'Exception',
    'PhutilLogFileChannel' => 'PhutilChannelChannel',
    'PhutilLunarPhase' => 'Phobject',
    'PhutilLunarPhaseTestCase' => 'PhutilTestCase',
    'PhutilMercurialBinaryAnalyzer' => 'PhutilBinaryAnalyzer',
    'PhutilMethodNotImplementedException' => 'Exception',
    'PhutilMetricsChannel' => 'PhutilChannelChannel',
    'PhutilMissingSymbolException' => 'Exception',
    'PhutilModuleUtilsTestCase' => 'PhutilTestCase',
    'PhutilNumber' => 'Phobject',
    'PhutilOAuth1Future' => 'FutureProxy',
    'PhutilOAuth1FutureTestCase' => 'PhutilTestCase',
    'PhutilOpaqueEnvelope' => 'Phobject',
    'PhutilOpaqueEnvelopeKey' => 'Phobject',
    'PhutilOpaqueEnvelopeTestCase' => 'PhutilTestCase',
    'PhutilPHPFragmentLexer' => 'PhutilLexer',
    'PhutilPHPFragmentLexerTestCase' => 'PhutilTestCase',
    'PhutilPHPObjectProtocolChannel' => 'PhutilProtocolChannel',
    'PhutilPHPObjectProtocolChannelTestCase' => 'PhutilTestCase',
    'PhutilParserGenerator' => 'Phobject',
    'PhutilParserGeneratorException' => 'Exception',
    'PhutilParserGeneratorTestCase' => 'PhutilTestCase',
    'PhutilPayPalAPIFuture' => 'FutureProxy',
    'PhutilPersonTest' => array(
      'Phobject',
      'PhutilPerson',
    ),
    'PhutilPhtTestCase' => 'PhutilTestCase',
    'PhutilPirateEnglishLocale' => 'PhutilLocale',
    'PhutilPortugueseBrazilLocale' => 'PhutilLocale',
    'PhutilPortuguesePortugalLocale' => 'PhutilLocale',
    'PhutilPostmarkFuture' => 'FutureProxy',
    'PhutilPregsprintfTestCase' => 'PhutilTestCase',
    'PhutilProcessQuery' => 'Phobject',
    'PhutilProcessRef' => 'Phobject',
    'PhutilProcessRefTestCase' => 'PhutilTestCase',
    'PhutilProgressSink' => 'Phobject',
    'PhutilProtocolChannel' => 'PhutilChannelChannel',
    'PhutilProxyException' => 'Exception',
    'PhutilProxyIterator' => array(
      'Phobject',
      'Iterator',
    ),
    'PhutilPygmentizeBinaryAnalyzer' => 'PhutilBinaryAnalyzer',
    'PhutilPythonFragmentLexer' => 'PhutilLexer',
    'PhutilQueryStringParser' => 'Phobject',
    'PhutilQueryStringParserTestCase' => 'PhutilTestCase',
    'PhutilRawEnglishLocale' => 'PhutilLocale',
    'PhutilReadableSerializer' => 'Phobject',
    'PhutilReadableSerializerTestCase' => 'PhutilTestCase',
    'PhutilRope' => 'Phobject',
    'PhutilRopeTestCase' => 'PhutilTestCase',
    'PhutilServiceProfiler' => 'Phobject',
    'PhutilShellLexer' => 'PhutilLexer',
    'PhutilShellLexerTestCase' => 'PhutilTestCase',
    'PhutilSignalHandler' => 'Phobject',
    'PhutilSignalRouter' => 'Phobject',
    'PhutilSimpleOptions' => 'Phobject',
    'PhutilSimpleOptionsLexer' => 'PhutilLexer',
    'PhutilSimpleOptionsLexerTestCase' => 'PhutilTestCase',
    'PhutilSimpleOptionsTestCase' => 'PhutilTestCase',
    'PhutilSimplifiedChineseLocale' => 'PhutilLocale',
    'PhutilSlackFuture' => 'FutureProxy',
    'PhutilSocketChannel' => 'PhutilChannel',
    'PhutilSortVector' => 'Phobject',
    'PhutilSpanishSpainLocale' => 'PhutilLocale',
    'PhutilStreamIterator' => array(
      'Phobject',
      'Iterator',
    ),
    'PhutilSubversionBinaryAnalyzer' => 'PhutilBinaryAnalyzer',
    'PhutilSystem' => 'Phobject',
    'PhutilSystemTestCase' => 'PhutilTestCase',
    'PhutilTerminalString' => 'Phobject',
    'PhutilTestCase' => 'Phobject',
    'PhutilTestCaseTestCase' => 'PhutilTestCase',
    'PhutilTestPhobject' => 'Phobject',
    'PhutilTestSkippedException' => 'Exception',
    'PhutilTestTerminatedException' => 'Exception',
    'PhutilTraditionalChineseLocale' => 'PhutilLocale',
    'PhutilTranslation' => 'Phobject',
    'PhutilTranslationTestCase' => 'PhutilTestCase',
    'PhutilTranslator' => 'Phobject',
    'PhutilTranslatorTestCase' => 'PhutilTestCase',
    'PhutilTsprintfTestCase' => 'PhutilTestCase',
    'PhutilTwitchFuture' => 'FutureProxy',
    'PhutilTypeCheckException' => 'Exception',
    'PhutilTypeExtraParametersException' => 'Exception',
    'PhutilTypeLexer' => 'PhutilLexer',
    'PhutilTypeMissingParametersException' => 'Exception',
    'PhutilTypeSpec' => 'Phobject',
    'PhutilTypeSpecTestCase' => 'PhutilTestCase',
    'PhutilURI' => 'Phobject',
    'PhutilURITestCase' => 'PhutilTestCase',
    'PhutilUSEnglishLocale' => 'PhutilLocale',
    'PhutilUTF8StringTruncator' => 'Phobject',
    'PhutilUTF8TestCase' => 'PhutilTestCase',
    'PhutilUnitTestEngine' => 'ArcanistUnitTestEngine',
    'PhutilUnitTestEngineTestCase' => 'PhutilTestCase',
    'PhutilUnknownSymbolParserGeneratorException' => 'PhutilParserGeneratorException',
    'PhutilUnreachableRuleParserGeneratorException' => 'PhutilParserGeneratorException',
    'PhutilUnreachableTerminalParserGeneratorException' => 'PhutilParserGeneratorException',
    'PhutilUrisprintfTestCase' => 'PhutilTestCase',
    'PhutilUtilsTestCase' => 'PhutilTestCase',
    'PhutilVeryWowEnglishLocale' => 'PhutilLocale',
    'PhutilWordPressFuture' => 'FutureProxy',
    'PhutilXHPASTBinary' => 'Phobject',
    'PytestTestEngine' => 'ArcanistUnitTestEngine',
    'TempFile' => 'Phobject',
    'TestAbstractDirectedGraph' => 'AbstractDirectedGraph',
    'XHPASTNode' => 'AASTNode',
    'XHPASTNodeTestCase' => 'PhutilTestCase',
    'XHPASTSyntaxErrorException' => 'Exception',
    'XHPASTToken' => 'AASTToken',
    'XHPASTTree' => 'AASTTree',
    'XHPASTTreeTestCase' => 'PhutilTestCase',
    'XUnitTestEngine' => 'ArcanistUnitTestEngine',
    'XUnitTestResultParserTestCase' => 'PhutilTestCase',
    'XsprintfUnknownConversionException' => 'InvalidArgumentException',
  ),
));
